*SRAM cells with certain initial logic value
*scalable lamda design rule

* Fei LI 
* NOTE: partially excerpted from Joe Basile's netlist but modified
*       and new types of cells are added
* 07/04/02

*(1) C_data1 : cell with initial data 1
*(2) C_data0 : cell with initial data 0
*(3) C_pref1_data0 : prefer-1 AC with initial data 0
*(4) C_pref1_data1 : prefer-1 AC with initial data 1
*(5) C_pref0_data1 : prefer-0 AC with initial data 1
*(6) C_pref0_data0 : prefer-0 AC with initial data 0
*(7) C_data1_H : cell with all high Vt transistors
*(8) C_data0_H : cell with all high Vt transistors

*(9) C_pref1_data0_EH : Even higher Vt + normal Vt
*(10) C_pref1_data1_EH : Even higher Vt + normal Vt
*(11) C_pref0_data1_EH : Even higher Vt + normal Vt
*(12) C_pref0_data0_EH : Even higher Vt + normal Vt
*(13) C_data1_EH : Even higher Vt
*(14) C_data0_EH : Even higher Vt

*(15) C_pref1_data0_HEH: High Vt + Even Higher Vt
*(16) C_pref1_data1_HEH: High Vt + Even Higher Vt
*(17) C_pref0_data1_HEH: High Vt + Even Higher Vt
*(18) C_pref0_data0_HEH: High Vt + Even Higher Vt
*-----------------------------------------------------------------
*NOTES: a. the cap on the bit line can be commented, and then
*		   you should put some load like gates at the top level
*		   netlist

*(1)
* parameters
* =================
* lmda: design rule parameters (set in the file parameters.sp)
* v_supply: supply votage (set in the file parameters.sp)
* v_supply_high: the high suppyl voltage in a dual voltage systme.

* ports of the subckt and their functions
* =======================================
* vsp: source for PMOS transistors in the x-coupled inverters
*      usually connected to Vdd or virtual Vdd
* vbp: bulk for the PMOS transistors in the SRAM cell
* vsn: source for NMOS transistors in the x-coupled inverters
*      usually connected to Gnd or virtual Gnd
* vbn: bulk for the NMOS transistors in the SRAM cell
* word: word line to select this cell; it can be used as write-enable
*       or read-enable
* bit:  data bit line (write/read)
* nbit: data-bar bit line (write/read)


.subckt C_data1 vsp vbp vsn vbn word bit nbit

*For 0.10um technology, l= 2*lmda = 0.10um
**eg. .param lmda=0.05u (this parameter will be set in file parameters.sp)

*m1 data ndata vsp vbp PMOS l='2*lmda' w='4*lmda' ad='32*lmda*lmda'
*+ as='32*lmda*lmda' pd='24*lmda' ps='24*lmda'
*m2 data ndata vsn vbn NMOS l='2*lmda' w='4.5*lmda' ad='40.5*lmda*lmda'
*+ as='40.5*lmda*lmda' pd='27*lmda' ps='27*lmda'
*m3 ndata data vsp vbp PMOS l='2*lmda' w='4*lmda' ad='32*lmda*lmda'
*+ as='32*lmda*lmda' pd='24*lmda' ps='24*lmda'
*m4 ndata data vsn vbn NMOS l='2*lmda' w='4.5*lmda' ad='40.5*lmda*lmda'
*+ as='40.5*lmda*lmda' pd='27*lmda' ps='27*lmda'
*m5 bit word data vbn NMOS l='2.75*lmda' w='3.5*lmda' ad='24.5*lmda*lmda'
*+ as='24.5*lmda*lmda' pd='21*lmda' ps='21*lmda'
*m6 nbit word ndata vbn NMOS l='2.75*lmda' w='3.5*lmda' ad='24.5*lmda*lmda'
*+ as='24.5*lmda*lmda' pd='21*lmda' ps='21*lmda'

m1 data ndata vsp vbp PMOS l='2*lmda' w='6.5*lmda' ad='32*lmda*lmda'
+ as='32*lmda*lmda' pd='24*lmda' ps='24*lmda'
m2 data ndata vsn vbn NMOS l='2*lmda' w='7.5*lmda' ad='40.5*lmda*lmda'
+ as='40.5*lmda*lmda' pd='27*lmda' ps='27*lmda'
m3 ndata data vsp vbp PMOS l='2*lmda' w='6.5*lmda' ad='32*lmda*lmda'
+ as='32*lmda*lmda' pd='24*lmda' ps='24*lmda'
m4 ndata data vsn vbn NMOS l='2*lmda' w='7.5*lmda' ad='40.5*lmda*lmda'
+ as='40.5*lmda*lmda' pd='27*lmda' ps='27*lmda'
m5 bit word data vbn NMOS l='2.75*lmda' w='3.5*lmda' ad='24.5*lmda*lmda'
+ as='24.5*lmda*lmda' pd='21*lmda' ps='21*lmda'
m6 nbit word ndata vbn NMOS l='2.75*lmda' w='3.5*lmda' ad='24.5*lmda*lmda'
+ as='24.5*lmda*lmda' pd='21*lmda' ps='21*lmda'

*Initialize node voltages (CHANGE FOR 0.07um)
.nodeset v(data)=v_supply
.nodeset v(ndata)=0

* use this typical value for each segment or connect to a gate?
*cbit bit 0 0.316442f
*cnbit nbit 0 0.316442f

.ends C_data1


*(2)
* parameters
* =================
* lmda: design rule parameters (set in the file parameters.sp)
* v_supply: supply votage (set in the file parameters.sp)
* v_supply_high: the high suppyl voltage in a dual voltage systme.

* ports of the subckt and their functions
* =======================================
* vsp: source for PMOS transistors in the x-coupled inverters
*      usually connected to Vdd or virtual Vdd
* vsn: source for NMOS transistors in the x-coupled inverters
*      usually connected to Gnd or virtual Gnd
* vbp: bulk for the PMOS transistors in the SRAM cell
* vbn: bulk for the NMOS transistors in the SRAM cell
* word: word line to select this cell; it can be used as write-enable
*       or read-enable
* bit:  data bit line (write/read)
* nbit: data-bar bit line (write/read)


.subckt C_data0 vsp vbp vsn vbn word bit nbit

*For 0.10um technology, l= 2*lmda = 0.10um
**eg. .param lmda=0.05u (this parameter will be set in file parameters.sp)

*m1 data ndata vsp vbp PMOS l='2*lmda' w='4*lmda' ad='32*lmda*lmda'
*+ as='32*lmda*lmda' pd='24*lmda' ps='24*lmda'
*m2 data ndata vsn vbn NMOS l='2*lmda' w='4.5*lmda' ad='40.5*lmda*lmda'
*+ as='40.5*lmda*lmda' pd='27*lmda' ps='27*lmda'
*m3 ndata data vsp vbp PMOS l='2*lmda' w='4*lmda' ad='32*lmda*lmda'
*+ as='32*lmda*lmda' pd='24*lmda' ps='24*lmda'
*m4 ndata data vsn vbn NMOS l='2*lmda' w='4.5*lmda' ad='40.5*lmda*lmda'
*+ as='40.5*lmda*lmda' pd='27*lmda' ps='27*lmda'
*m5 bit word data vbn NMOS l='2.75*lmda' w='3.5*lmda' ad='24.5*lmda*lmda'
*+ as='24.5*lmda*lmda' pd='21*lmda' ps='21*lmda'
*m6 nbit word ndata vbn NMOS l='2.75*lmda' w='3.5*lmda' ad='24.5*lmda*lmda'
*+ as='24.5*lmda*lmda' pd='21*lmda' ps='21*lmda'

m1 data ndata vsp vbp PMOS l='2*lmda' w='6.5*lmda' ad='32*lmda*lmda'
+ as='32*lmda*lmda' pd='24*lmda' ps='24*lmda'
m2 data ndata vsn vbn NMOS l='2*lmda' w='7.5*lmda' ad='40.5*lmda*lmda'
+ as='40.5*lmda*lmda' pd='27*lmda' ps='27*lmda'
m3 ndata data vsp vbp PMOS l='2*lmda' w='6.5*lmda' ad='32*lmda*lmda'
+ as='32*lmda*lmda' pd='24*lmda' ps='24*lmda'
m4 ndata data vsn vbn NMOS l='2*lmda' w='7.5*lmda' ad='40.5*lmda*lmda'
+ as='40.5*lmda*lmda' pd='27*lmda' ps='27*lmda'
m5 bit word data vbn NMOS l='2.75*lmda' w='3.5*lmda' ad='24.5*lmda*lmda'
+ as='24.5*lmda*lmda' pd='21*lmda' ps='21*lmda'
m6 nbit word ndata vbn NMOS l='2.75*lmda' w='3.5*lmda' ad='24.5*lmda*lmda'
+ as='24.5*lmda*lmda' pd='21*lmda' ps='21*lmda'

*Initialize node voltages (CHANGE FOR 0.07um)
.nodeset v(data)=0
.nodeset v(ndata)=v_supply

* use this typical value for each segment or connect to a gate?
*cbit bit 0 0.316442f
*cnbit nbit 0 0.316442f

.ends C_data0

*(3)
* parameters
* =================
* lmda: design rule parameters (set in the file parameters.sp)
* v_supply: supply votage (set in the file parameters.sp)
* v_supply_high: the high suppyl voltage in a dual voltage systme.

* ports of the subckt and their functions
* =======================================
* vsp: source for PMOS transistors in the x-coupled inverters
*      usually connected to Vdd or virtual Vdd
* vsn: source for NMOS transistors in the x-coupled inverters
*      usually connected to Gnd or virtual Gnd
* vbp: bulk for the PMOS transistors in the SRAM cell
* vbn: bulk for the NMOS transistors in the SRAM cell
* word: word line to select this cell; it can be used as write-enable
*       or read-enable
* bit:  data bit line (write/read)
* nbit: data-bar bit line (write/read)


.subckt C_pref1_data0 vsp vbp vsn vbn word bit nbit

*For 0.10um technology, l= 2*lmda = 0.10um
**eg. .param lmda=0.05u (this parameter will be set in file parameters.sp)

*m1 data ndata vsp vbp PMOS l='2*lmda' w='4*lmda' ad='32*lmda*lmda'
*+ as='32*lmda*lmda' pd='24*lmda' ps='24*lmda'
*m2 data ndata vsn vbn NMOS_H l='2*lmda' w='4.5*lmda' ad='40.5*lmda*lmda'
*+ as='40.5*lmda*lmda' pd='27*lmda' ps='27*lmda'
*m3 ndata data vsp vbp PMOS_H l='2*lmda' w='4*lmda' ad='32*lmda*lmda'
*+ as='32*lmda*lmda' pd='24*lmda' ps='24*lmda'
*m4 ndata data vsn vbn NMOS l='2*lmda' w='4.5*lmda' ad='40.5*lmda*lmda'
*+ as='40.5*lmda*lmda' pd='27*lmda' ps='27*lmda'
*m5 bit word data vbn NMOS l='2.75*lmda' w='3.5*lmda' ad='24.5*lmda*lmda'
*+ as='24.5*lmda*lmda' pd='21*lmda' ps='21*lmda'
*m6 nbit word ndata vbn NMOS_H l='2.75*lmda' w='3.5*lmda' ad='24.5*lmda*lmda'
*+ as='24.5*lmda*lmda' pd='21*lmda' ps='21*lmda'

m1 data ndata vsp vbp PMOS l='2*lmda' w='6.5*lmda' ad='32*lmda*lmda'
+ as='32*lmda*lmda' pd='24*lmda' ps='24*lmda'
m2 data ndata vsn vbn NMOS_H l='2*lmda' w='7.5*lmda' ad='40.5*lmda*lmda'
+ as='40.5*lmda*lmda' pd='27*lmda' ps='27*lmda'
m3 ndata data vsp vbp PMOS_H l='2*lmda' w='6.5*lmda' ad='32*lmda*lmda'
+ as='32*lmda*lmda' pd='24*lmda' ps='24*lmda'
m4 ndata data vsn vbn NMOS l='2*lmda' w='7.5*lmda' ad='40.5*lmda*lmda'
+ as='40.5*lmda*lmda' pd='27*lmda' ps='27*lmda'
m5 bit word data vbn NMOS l='2.75*lmda' w='3.5*lmda' ad='24.5*lmda*lmda'
+ as='24.5*lmda*lmda' pd='21*lmda' ps='21*lmda'
m6 nbit word ndata vbn NMOS_H l='2.75*lmda' w='3.5*lmda' ad='24.5*lmda*lmda'
+ as='24.5*lmda*lmda' pd='21*lmda' ps='21*lmda'

*Initialize node voltages (CHANGE FOR 0.07um)
.nodeset v(data)=0
.nodeset v(ndata)=v_supply

* use this typical value for each segment or connect to a gate?
*cbit bit 0 0.316442f
*cnbit nbit 0 0.316442f

.ends C_pref1_data0

*(4)
* parameters
* =================
* lmda: design rule parameters (set in the file parameters.sp)
* v_supply: supply votage (set in the file parameters.sp)
* v_supply_high: the high suppyl voltage in a dual voltage systme.

* ports of the subckt and their functions
* =======================================
* vsp: source for PMOS transistors in the x-coupled inverters
*      usually connected to Vdd or virtual Vdd
* vsn: source for NMOS transistors in the x-coupled inverters
*      usually connected to Gnd or virtual Gnd
* vbp: bulk for the PMOS transistors in the SRAM cell
* vbn: bulk for the NMOS transistors in the SRAM cell
* word: word line to select this cell; it can be used as write-enable
*       or read-enable
* bit:  data bit line (write/read)
* nbit: data-bar bit line (write/read)


.subckt C_pref1_data1 vsp vbp vsn vbn word bit nbit

*For 0.10um technology, l= 2*lmda = 0.10um
**eg. .param lmda=0.05u (this parameter will be set in file parameters.sp)

*m1 data ndata vsp vbp PMOS l='2*lmda' w='4*lmda' ad='32*lmda*lmda'
*+ as='32*lmda*lmda' pd='24*lmda' ps='24*lmda'
*m2 data ndata vsn vbn NMOS_H l='2*lmda' w='4.5*lmda' ad='40.5*lmda*lmda'
*+ as='40.5*lmda*lmda' pd='27*lmda' ps='27*lmda'
*m3 ndata data vsp vbp PMOS_H l='2*lmda' w='4*lmda' ad='32*lmda*lmda'
*+ as='32*lmda*lmda' pd='24*lmda' ps='24*lmda'
*m4 ndata data vsn vbn NMOS l='2*lmda' w='4.5*lmda' ad='40.5*lmda*lmda'
*+ as='40.5*lmda*lmda' pd='27*lmda' ps='27*lmda'
*m5 bit word data vbn NMOS l='2.75*lmda' w='3.5*lmda' ad='24.5*lmda*lmda'
*+ as='24.5*lmda*lmda' pd='21*lmda' ps='21*lmda'
*m6 nbit word ndata vbn NMOS_H l='2.75*lmda' w='3.5*lmda' ad='24.5*lmda*lmda'
*+ as='24.5*lmda*lmda' pd='21*lmda' ps='21*lmda'

m1 data ndata vsp vbp PMOS l='2*lmda' w='6.5*lmda' ad='32*lmda*lmda'
+ as='32*lmda*lmda' pd='24*lmda' ps='24*lmda'
m2 data ndata vsn vbn NMOS_H l='2*lmda' w='7.5*lmda' ad='40.5*lmda*lmda'
+ as='40.5*lmda*lmda' pd='27*lmda' ps='27*lmda'
m3 ndata data vsp vbp PMOS_H l='2*lmda' w='6.5*lmda' ad='32*lmda*lmda'
+ as='32*lmda*lmda' pd='24*lmda' ps='24*lmda'
m4 ndata data vsn vbn NMOS l='2*lmda' w='7.5*lmda' ad='40.5*lmda*lmda'
+ as='40.5*lmda*lmda' pd='27*lmda' ps='27*lmda'
m5 bit word data vbn NMOS l='2.75*lmda' w='3.5*lmda' ad='24.5*lmda*lmda'
+ as='24.5*lmda*lmda' pd='21*lmda' ps='21*lmda'
m6 nbit word ndata vbn NMOS_H l='2.75*lmda' w='3.5*lmda' ad='24.5*lmda*lmda'
+ as='24.5*lmda*lmda' pd='21*lmda' ps='21*lmda'

*Initialize node voltages (CHANGE FOR 0.07um)
.nodeset v(data)=v_supply
.nodeset v(ndata)=0

* use this typical value for each segment or connect to a gate?
*cbit bit 0 0.316442f
*cnbit nbit 0 0.316442f

.ends C_pref1_data1

*(5)
* parameters
* =================
* lmda: design rule parameters (set in the file parameters.sp)
* v_supply: supply votage (set in the file parameters.sp)
* v_supply_high: the high suppyl voltage in a dual voltage systme.

* ports of the subckt and their functions
* =======================================
* vsp: source for PMOS transistors in the x-coupled inverters
*      usually connected to Vdd or virtual Vdd
* vsn: source for NMOS transistors in the x-coupled inverters
*      usually connected to Gnd or virtual Gnd
* vbp: bulk for the PMOS transistors in the SRAM cell
* vbn: bulk for the NMOS transistors in the SRAM cell
* word: word line to select this cell; it can be used as write-enable
*       or read-enable
* bit:  data bit line (write/read)
* nbit: data-bar bit line (write/read)


.subckt C_pref0_data1 vsp vbp vsn vbn word bit nbit

*For 0.10um technology, l= 2*lmda = 0.10um
**eg. .param lmda=0.05u (this parameter will be set in file parameters.sp)

*m1 data ndata vsp vbp PMOS_H l='2*lmda' w='4*lmda' ad='32*lmda*lmda'
*+ as='32*lmda*lmda' pd='24*lmda' ps='24*lmda'
*m2 data ndata vsn vbn NMOS l='2*lmda' w='4.5*lmda' ad='40.5*lmda*lmda'
*+ as='40.5*lmda*lmda' pd='27*lmda' ps='27*lmda'
*m3 ndata data vsp vbp PMOS l='2*lmda' w='4*lmda' ad='32*lmda*lmda'
*+ as='32*lmda*lmda' pd='24*lmda' ps='24*lmda'
*m4 ndata data vsn vbn NMOS_H l='2*lmda' w='4.5*lmda' ad='40.5*lmda*lmda'
*+ as='40.5*lmda*lmda' pd='27*lmda' ps='27*lmda'
*m5 bit word data vbn NMOS_H l='2.75*lmda' w='3.5*lmda' ad='24.5*lmda*lmda'
*+ as='24.5*lmda*lmda' pd='21*lmda' ps='21*lmda'
*m6 nbit word ndata vbn NMOS l='2.75*lmda' w='3.5*lmda' ad='24.5*lmda*lmda'
*+ as='24.5*lmda*lmda' pd='21*lmda' ps='21*lmda'

m1 data ndata vsp vbp PMOS_H l='2*lmda' w='6.5*lmda' ad='32*lmda*lmda'
+ as='32*lmda*lmda' pd='24*lmda' ps='24*lmda'
m2 data ndata vsn vbn NMOS l='2*lmda' w='7.5*lmda' ad='40.5*lmda*lmda'
+ as='40.5*lmda*lmda' pd='27*lmda' ps='27*lmda'
m3 ndata data vsp vbp PMOS l='2*lmda' w='6.5*lmda' ad='32*lmda*lmda'
+ as='32*lmda*lmda' pd='24*lmda' ps='24*lmda'
m4 ndata data vsn vbn NMOS_H l='2*lmda' w='7.5*lmda' ad='40.5*lmda*lmda'
+ as='40.5*lmda*lmda' pd='27*lmda' ps='27*lmda'
m5 bit word data vbn NMOS_H l='2.75*lmda' w='3.5*lmda' ad='24.5*lmda*lmda'
+ as='24.5*lmda*lmda' pd='21*lmda' ps='21*lmda'
m6 nbit word ndata vbn NMOS l='2.75*lmda' w='3.5*lmda' ad='24.5*lmda*lmda'
+ as='24.5*lmda*lmda' pd='21*lmda' ps='21*lmda'

*Initialize node voltages (CHANGE FOR 0.07um)
.nodeset v(data)=v_supply
.nodeset v(ndata)=0

* use this typical value for each segment or connect to a gate?
*cbit bit 0 0.316442f
*cnbit nbit 0 0.316442f

.ends C_pref0_data1

*(6)
* parameters
* =================
* lmda: design rule parameters (set in the file parameters.sp)
* v_supply: supply votage (set in the file parameters.sp)
* v_supply_high: the high suppyl voltage in a dual voltage systme.

* ports of the subckt and their functions
* =======================================
* vsp: source for PMOS transistors in the x-coupled inverters
*      usually connected to Vdd or virtual Vdd
* vsn: source for NMOS transistors in the x-coupled inverters
*      usually connected to Gnd or virtual Gnd
* vbp: bulk for the PMOS transistors in the SRAM cell
* vbn: bulk for the NMOS transistors in the SRAM cell
* word: word line to select this cell; it can be used as write-enable
*       or read-enable
* bit:  data bit line (write/read)
* nbit: data-bar bit line (write/read)


.subckt C_pref0_data0 vsp vbp vsn vbn word bit nbit

*For 0.10um technology, l= 2*lmda = 0.10um
**eg. .param lmda=0.05u (this parameter will be set in file parameters.sp)

*m1 data ndata vsp vbp PMOS_H l='2*lmda' w='4*lmda' ad='32*lmda*lmda'
*+ as='32*lmda*lmda' pd='24*lmda' ps='24*lmda'
*m2 data ndata vsn vbn NMOS l='2*lmda' w='4.5*lmda' ad='40.5*lmda*lmda'
*+ as='40.5*lmda*lmda' pd='27*lmda' ps='27*lmda'
*m3 ndata data vsp vbp PMOS l='2*lmda' w='4*lmda' ad='32*lmda*lmda'
*+ as='32*lmda*lmda' pd='24*lmda' ps='24*lmda'
*m4 ndata data vsn vbn NMOS_H l='2*lmda' w='4.5*lmda' ad='40.5*lmda*lmda'
*+ as='40.5*lmda*lmda' pd='27*lmda' ps='27*lmda'
*m5 bit word data vbn NMOS_H l='2.75*lmda' w='3.5*lmda' ad='24.5*lmda*lmda'
*+ as='24.5*lmda*lmda' pd='21*lmda' ps='21*lmda'
*m6 nbit word ndata vbn NMOS l='2.75*lmda' w='3.5*lmda' ad='24.5*lmda*lmda'
*+ as='24.5*lmda*lmda' pd='21*lmda' ps='21*lmda'

m1 data ndata vsp vbp PMOS_H l='2*lmda' w='6.5*lmda' ad='32*lmda*lmda'
+ as='32*lmda*lmda' pd='24*lmda' ps='24*lmda'
m2 data ndata vsn vbn NMOS l='2*lmda' w='7.5*lmda' ad='40.5*lmda*lmda'
+ as='40.5*lmda*lmda' pd='27*lmda' ps='27*lmda'
m3 ndata data vsp vbp PMOS l='2*lmda' w='6.5*lmda' ad='32*lmda*lmda'
+ as='32*lmda*lmda' pd='24*lmda' ps='24*lmda'
m4 ndata data vsn vbn NMOS_H l='2*lmda' w='7.5*lmda' ad='40.5*lmda*lmda'
+ as='40.5*lmda*lmda' pd='27*lmda' ps='27*lmda'
m5 bit word data vbn NMOS_H l='2.75*lmda' w='3.5*lmda' ad='24.5*lmda*lmda'
+ as='24.5*lmda*lmda' pd='21*lmda' ps='21*lmda'
m6 nbit word ndata vbn NMOS l='2.75*lmda' w='3.5*lmda' ad='24.5*lmda*lmda'
+ as='24.5*lmda*lmda' pd='21*lmda' ps='21*lmda'

*Initialize node voltages (CHANGE FOR 0.07um)
.nodeset v(data)=0
.nodeset v(ndata)=v_supply

* use this typical value for each segment or connect to a gate?
*cbit bit 0 0.316442f
*cnbit nbit 0 0.316442f

.ends C_pref0_data0

*(7)
* parameters
* =================
* lmda: design rule parameters (set in the file parameters.sp)
* v_supply: supply votage (set in the file parameters.sp)
* v_supply_high: the high suppyl voltage in a dual voltage systme.

* ports of the subckt and their functions
* =======================================
* vsp: source for PMOS transistors in the x-coupled inverters
*      usually connected to Vdd or virtual Vdd
* vbp: bulk for the PMOS transistors in the SRAM cell
* vsn: source for NMOS transistors in the x-coupled inverters
*      usually connected to Gnd or virtual Gnd
* vbn: bulk for the NMOS transistors in the SRAM cell
* word: word line to select this cell; it can be used as write-enable
*       or read-enable
* bit:  data bit line (write/read)
* nbit: data-bar bit line (write/read)


.subckt C_data1_H vsp vbp vsn vbn word bit nbit

*For 0.10um technology, l= 2*lmda = 0.10um
**eg. .param lmda=0.05u (this parameter will be set in file parameters.sp)

*m1 data ndata vsp vbp PMOS_H l='2*lmda' w='4*lmda' ad='32*lmda*lmda'
*+ as='32*lmda*lmda' pd='24*lmda' ps='24*lmda'
*m2 data ndata vsn vbn NMOS_H l='2*lmda' w='4.5*lmda' ad='40.5*lmda*lmda'
*+ as='40.5*lmda*lmda' pd='27*lmda' ps='27*lmda'
*m3 ndata data vsp vbp PMOS_H l='2*lmda' w='4*lmda' ad='32*lmda*lmda'
*+ as='32*lmda*lmda' pd='24*lmda' ps='24*lmda'
*m4 ndata data vsn vbn NMOS_H l='2*lmda' w='4.5*lmda' ad='40.5*lmda*lmda'
*+ as='40.5*lmda*lmda' pd='27*lmda' ps='27*lmda'
*m5 bit word data vbn NMOS_H l='2.75*lmda' w='3.5*lmda' ad='24.5*lmda*lmda'
*+ as='24.5*lmda*lmda' pd='21*lmda' ps='21*lmda'
*m6 nbit word ndata vbn NMOS_H l='2.75*lmda' w='3.5*lmda' ad='24.5*lmda*lmda'
*+ as='24.5*lmda*lmda' pd='21*lmda' ps='21*lmda'

m1 data ndata vsp vbp PMOS_H l='2*lmda' w='6.5*lmda' ad='32*lmda*lmda'
+ as='32*lmda*lmda' pd='24*lmda' ps='24*lmda'
m2 data ndata vsn vbn NMOS_H l='2*lmda' w='7.5*lmda' ad='40.5*lmda*lmda'
+ as='40.5*lmda*lmda' pd='27*lmda' ps='27*lmda'
m3 ndata data vsp vbp PMOS_H l='2*lmda' w='6.5*lmda' ad='32*lmda*lmda'
+ as='32*lmda*lmda' pd='24*lmda' ps='24*lmda'
m4 ndata data vsn vbn NMOS_H l='2*lmda' w='7.5*lmda' ad='40.5*lmda*lmda'
+ as='40.5*lmda*lmda' pd='27*lmda' ps='27*lmda'
m5 bit word data vbn NMOS_H l='2.75*lmda' w='3.5*lmda' ad='24.5*lmda*lmda'
+ as='24.5*lmda*lmda' pd='21*lmda' ps='21*lmda'
m6 nbit word ndata vbn NMOS_H l='2.75*lmda' w='3.5*lmda' ad='24.5*lmda*lmda'
+ as='24.5*lmda*lmda' pd='21*lmda' ps='21*lmda'

*Initialize node voltages (CHANGE FOR 0.07um)
.nodeset v(data)=v_supply
.nodeset v(ndata)=0

* use this typical value for each segment or connect to a gate?
*cbit bit 0 0.316442f
*cnbit nbit 0 0.316442f

.ends C_data1_H


*(8)
* parameters
* =================
* lmda: design rule parameters (set in the file parameters.sp)
* v_supply: supply votage (set in the file parameters.sp)
* v_supply_high: the high suppyl voltage in a dual voltage systme.

* ports of the subckt and their functions
* =======================================
* vsp: source for PMOS transistors in the x-coupled inverters
*      usually connected to Vdd or virtual Vdd
* vsn: source for NMOS transistors in the x-coupled inverters
*      usually connected to Gnd or virtual Gnd
* vbp: bulk for the PMOS transistors in the SRAM cell
* vbn: bulk for the NMOS transistors in the SRAM cell
* word: word line to select this cell; it can be used as write-enable
*       or read-enable
* bit:  data bit line (write/read)
* nbit: data-bar bit line (write/read)


.subckt C_data0_H vsp vbp vsn vbn word bit nbit

*For 0.10um technology, l= 2*lmda = 0.10um
**eg. .param lmda=0.05u (this parameter will be set in file parameters.sp)

*m1 data ndata vsp vbp PMOS_H l='2*lmda' w='4*lmda' ad='32*lmda*lmda'
*+ as='32*lmda*lmda' pd='24*lmda' ps='24*lmda'
*m2 data ndata vsn vbn NMOS_H l='2*lmda' w='4.5*lmda' ad='40.5*lmda*lmda'
*+ as='40.5*lmda*lmda' pd='27*lmda' ps='27*lmda'
*m3 ndata data vsp vbp PMOS_H l='2*lmda' w='4*lmda' ad='32*lmda*lmda'
*+ as='32*lmda*lmda' pd='24*lmda' ps='24*lmda'
*m4 ndata data vsn vbn NMOS_H l='2*lmda' w='4.5*lmda' ad='40.5*lmda*lmda'
*+ as='40.5*lmda*lmda' pd='27*lmda' ps='27*lmda'
*m5 bit word data vbn NMOS_H l='2.75*lmda' w='3.5*lmda' ad='24.5*lmda*lmda'
*+ as='24.5*lmda*lmda' pd='21*lmda' ps='21*lmda'
*m6 nbit word ndata vbn NMOS_H l='2.75*lmda' w='3.5*lmda' ad='24.5*lmda*lmda'
*+ as='24.5*lmda*lmda' pd='21*lmda' ps='21*lmda'

m1 data ndata vsp vbp PMOS_H l='2*lmda' w='6.5*lmda' ad='32*lmda*lmda'
+ as='32*lmda*lmda' pd='24*lmda' ps='24*lmda'
m2 data ndata vsn vbn NMOS_H l='2*lmda' w='7.5*lmda' ad='40.5*lmda*lmda'
+ as='40.5*lmda*lmda' pd='27*lmda' ps='27*lmda'
m3 ndata data vsp vbp PMOS_H l='2*lmda' w='6.5*lmda' ad='32*lmda*lmda'
+ as='32*lmda*lmda' pd='24*lmda' ps='24*lmda'
m4 ndata data vsn vbn NMOS_H l='2*lmda' w='7.5*lmda' ad='40.5*lmda*lmda'
+ as='40.5*lmda*lmda' pd='27*lmda' ps='27*lmda'
m5 bit word data vbn NMOS_H l='2.75*lmda' w='3.5*lmda' ad='24.5*lmda*lmda'
+ as='24.5*lmda*lmda' pd='21*lmda' ps='21*lmda'
m6 nbit word ndata vbn NMOS_H l='2.75*lmda' w='3.5*lmda' ad='24.5*lmda*lmda'
+ as='24.5*lmda*lmda' pd='21*lmda' ps='21*lmda'

*Initialize node voltages (CHANGE FOR 0.07um)
.nodeset v(data)=0
.nodeset v(ndata)=v_supply

* use this typical value for each segment or connect to a gate?
*cbit bit 0 0.316442f
*cnbit nbit 0 0.316442f

.ends C_data0_H

*---------------------------------------------------------------

*(9)
* parameters
* =================
* lmda: design rule parameters (set in the file parameters.sp)
* v_supply: supply votage (set in the file parameters.sp)
* v_supply_high: the high suppyl voltage in a dual voltage systme.

* ports of the subckt and their functions
* =======================================
* vsp: source for PMOS transistors in the x-coupled inverters
*      usually connected to Vdd or virtual Vdd
* vsn: source for NMOS transistors in the x-coupled inverters
*      usually connected to Gnd or virtual Gnd
* vbp: bulk for the PMOS transistors in the SRAM cell
* vbn: bulk for the NMOS transistors in the SRAM cell
* word: word line to select this cell; it can be used as write-enable
*       or read-enable
* bit:  data bit line (write/read)
* nbit: data-bar bit line (write/read)


.subckt C_pref1_data0_EH vsp vbp vsn vbn word bit nbit

*For 0.10um technology, l= 2*lmda = 0.10um
**eg. .param lmda=0.05u (this parameter will be set in file parameters.sp)

*m1 data ndata vsp vbp PMOS l='2*lmda' w='4*lmda' ad='32*lmda*lmda'
*+ as='32*lmda*lmda' pd='24*lmda' ps='24*lmda'
*m2 data ndata vsn vbn NMOS_H l='2*lmda' w='4.5*lmda' ad='40.5*lmda*lmda'
*+ as='40.5*lmda*lmda' pd='27*lmda' ps='27*lmda'
*m3 ndata data vsp vbp PMOS_H l='2*lmda' w='4*lmda' ad='32*lmda*lmda'
*+ as='32*lmda*lmda' pd='24*lmda' ps='24*lmda'
*m4 ndata data vsn vbn NMOS l='2*lmda' w='4.5*lmda' ad='40.5*lmda*lmda'
*+ as='40.5*lmda*lmda' pd='27*lmda' ps='27*lmda'
*m5 bit word data vbn NMOS l='2.75*lmda' w='3.5*lmda' ad='24.5*lmda*lmda'
*+ as='24.5*lmda*lmda' pd='21*lmda' ps='21*lmda'
*m6 nbit word ndata vbn NMOS_H l='2.75*lmda' w='3.5*lmda' ad='24.5*lmda*lmda'
*+ as='24.5*lmda*lmda' pd='21*lmda' ps='21*lmda'

m1 data ndata vsp vbp PMOS l='2*lmda' w='8.0*lmda' ad='32*lmda*lmda'
+ as='32*lmda*lmda' pd='24*lmda' ps='24*lmda'
m2 data ndata vsn vbn NMOS_EH l='2*lmda' w='8.5*lmda' ad='40.5*lmda*lmda'
+ as='40.5*lmda*lmda' pd='27*lmda' ps='27*lmda'
m3 ndata data vsp vbp PMOS_EH l='2*lmda' w='8.0*lmda' ad='32*lmda*lmda'
+ as='32*lmda*lmda' pd='24*lmda' ps='24*lmda'
m4 ndata data vsn vbn NMOS l='2*lmda' w='8.5*lmda' ad='40.5*lmda*lmda'
+ as='40.5*lmda*lmda' pd='27*lmda' ps='27*lmda'
m5 bit word data vbn NMOS l='2.75*lmda' w='3.5*lmda' ad='24.5*lmda*lmda'
+ as='24.5*lmda*lmda' pd='21*lmda' ps='21*lmda'
m6 nbit word ndata vbn NMOS_EH l='2.75*lmda' w='3.5*lmda' ad='24.5*lmda*lmda'
+ as='24.5*lmda*lmda' pd='21*lmda' ps='21*lmda'

*Initialize node voltages (CHANGE FOR 0.07um)
.nodeset v(data)=0
.nodeset v(ndata)=v_supply

* use this typical value for each segment or connect to a gate?
*cbit bit 0 0.316442f
*cnbit nbit 0 0.316442f

.ends C_pref1_data0_EH

*(10)
* parameters
* =================
* lmda: design rule parameters (set in the file parameters.sp)
* v_supply: supply votage (set in the file parameters.sp)
* v_supply_high: the high suppyl voltage in a dual voltage systme.

* ports of the subckt and their functions
* =======================================
* vsp: source for PMOS transistors in the x-coupled inverters
*      usually connected to Vdd or virtual Vdd
* vsn: source for NMOS transistors in the x-coupled inverters
*      usually connected to Gnd or virtual Gnd
* vbp: bulk for the PMOS transistors in the SRAM cell
* vbn: bulk for the NMOS transistors in the SRAM cell
* word: word line to select this cell; it can be used as write-enable
*       or read-enable
* bit:  data bit line (write/read)
* nbit: data-bar bit line (write/read)


.subckt C_pref1_data1_EH vsp vbp vsn vbn word bit nbit

*For 0.10um technology, l= 2*lmda = 0.10um
**eg. .param lmda=0.05u (this parameter will be set in file parameters.sp)

*m1 data ndata vsp vbp PMOS l='2*lmda' w='4*lmda' ad='32*lmda*lmda'
*+ as='32*lmda*lmda' pd='24*lmda' ps='24*lmda'
*m2 data ndata vsn vbn NMOS_H l='2*lmda' w='4.5*lmda' ad='40.5*lmda*lmda'
*+ as='40.5*lmda*lmda' pd='27*lmda' ps='27*lmda'
*m3 ndata data vsp vbp PMOS_H l='2*lmda' w='4*lmda' ad='32*lmda*lmda'
*+ as='32*lmda*lmda' pd='24*lmda' ps='24*lmda'
*m4 ndata data vsn vbn NMOS l='2*lmda' w='4.5*lmda' ad='40.5*lmda*lmda'
*+ as='40.5*lmda*lmda' pd='27*lmda' ps='27*lmda'
*m5 bit word data vbn NMOS l='2.75*lmda' w='3.5*lmda' ad='24.5*lmda*lmda'
*+ as='24.5*lmda*lmda' pd='21*lmda' ps='21*lmda'
*m6 nbit word ndata vbn NMOS_H l='2.75*lmda' w='3.5*lmda' ad='24.5*lmda*lmda'
*+ as='24.5*lmda*lmda' pd='21*lmda' ps='21*lmda'

m1 data ndata vsp vbp PMOS l='2*lmda' w='8.0*lmda' ad='32*lmda*lmda'
+ as='32*lmda*lmda' pd='24*lmda' ps='24*lmda'
m2 data ndata vsn vbn NMOS_EH l='2*lmda' w='8.5*lmda' ad='40.5*lmda*lmda'
+ as='40.5*lmda*lmda' pd='27*lmda' ps='27*lmda'
m3 ndata data vsp vbp PMOS_EH l='2*lmda' w='8.0*lmda' ad='32*lmda*lmda'
+ as='32*lmda*lmda' pd='24*lmda' ps='24*lmda'
m4 ndata data vsn vbn NMOS l='2*lmda' w='8.5*lmda' ad='40.5*lmda*lmda'
+ as='40.5*lmda*lmda' pd='27*lmda' ps='27*lmda'
m5 bit word data vbn NMOS l='2.75*lmda' w='3.5*lmda' ad='24.5*lmda*lmda'
+ as='24.5*lmda*lmda' pd='21*lmda' ps='21*lmda'
m6 nbit word ndata vbn NMOS_EH l='2.75*lmda' w='3.5*lmda' ad='24.5*lmda*lmda'
+ as='24.5*lmda*lmda' pd='21*lmda' ps='21*lmda'

*Initialize node voltages (CHANGE FOR 0.07um)
.nodeset v(data)=v_supply
.nodeset v(ndata)=0

* use this typical value for each segment or connect to a gate?
*cbit bit 0 0.316442f
*cnbit nbit 0 0.316442f

.ends C_pref1_data1_EH

*(11)
* parameters
* =================
* lmda: design rule parameters (set in the file parameters.sp)
* v_supply: supply votage (set in the file parameters.sp)
* v_supply_high: the high suppyl voltage in a dual voltage systme.

* ports of the subckt and their functions
* =======================================
* vsp: source for PMOS transistors in the x-coupled inverters
*      usually connected to Vdd or virtual Vdd
* vsn: source for NMOS transistors in the x-coupled inverters
*      usually connected to Gnd or virtual Gnd
* vbp: bulk for the PMOS transistors in the SRAM cell
* vbn: bulk for the NMOS transistors in the SRAM cell
* word: word line to select this cell; it can be used as write-enable
*       or read-enable
* bit:  data bit line (write/read)
* nbit: data-bar bit line (write/read)


.subckt C_pref0_data1_EH vsp vbp vsn vbn word bit nbit

*For 0.10um technology, l= 2*lmda = 0.10um
**eg. .param lmda=0.05u (this parameter will be set in file parameters.sp)

*m1 data ndata vsp vbp PMOS_H l='2*lmda' w='4*lmda' ad='32*lmda*lmda'
*+ as='32*lmda*lmda' pd='24*lmda' ps='24*lmda'
*m2 data ndata vsn vbn NMOS l='2*lmda' w='4.5*lmda' ad='40.5*lmda*lmda'
*+ as='40.5*lmda*lmda' pd='27*lmda' ps='27*lmda'
*m3 ndata data vsp vbp PMOS l='2*lmda' w='4*lmda' ad='32*lmda*lmda'
*+ as='32*lmda*lmda' pd='24*lmda' ps='24*lmda'
*m4 ndata data vsn vbn NMOS_H l='2*lmda' w='4.5*lmda' ad='40.5*lmda*lmda'
*+ as='40.5*lmda*lmda' pd='27*lmda' ps='27*lmda'
*m5 bit word data vbn NMOS_H l='2.75*lmda' w='3.5*lmda' ad='24.5*lmda*lmda'
*+ as='24.5*lmda*lmda' pd='21*lmda' ps='21*lmda'
*m6 nbit word ndata vbn NMOS l='2.75*lmda' w='3.5*lmda' ad='24.5*lmda*lmda'
*+ as='24.5*lmda*lmda' pd='21*lmda' ps='21*lmda'

m1 data ndata vsp vbp PMOS_EH l='2*lmda' w='8.0*lmda' ad='32*lmda*lmda'
+ as='32*lmda*lmda' pd='24*lmda' ps='24*lmda'
m2 data ndata vsn vbn NMOS l='2*lmda' w='8.5*lmda' ad='40.5*lmda*lmda'
+ as='40.5*lmda*lmda' pd='27*lmda' ps='27*lmda'
m3 ndata data vsp vbp PMOS l='2*lmda' w='8.0*lmda' ad='32*lmda*lmda'
+ as='32*lmda*lmda' pd='24*lmda' ps='24*lmda'
m4 ndata data vsn vbn NMOS_EH l='2*lmda' w='8.5*lmda' ad='40.5*lmda*lmda'
+ as='40.5*lmda*lmda' pd='27*lmda' ps='27*lmda'
m5 bit word data vbn NMOS_EH l='2.75*lmda' w='3.5*lmda' ad='24.5*lmda*lmda'
+ as='24.5*lmda*lmda' pd='21*lmda' ps='21*lmda'
m6 nbit word ndata vbn NMOS l='2.75*lmda' w='3.5*lmda' ad='24.5*lmda*lmda'
+ as='24.5*lmda*lmda' pd='21*lmda' ps='21*lmda'

*Initialize node voltages (CHANGE FOR 0.07um)
.nodeset v(data)=v_supply
.nodeset v(ndata)=0

* use this typical value for each segment or connect to a gate?
*cbit bit 0 0.316442f
*cnbit nbit 0 0.316442f

.ends C_pref0_data1_EH

*(12)
* parameters
* =================
* lmda: design rule parameters (set in the file parameters.sp)
* v_supply: supply votage (set in the file parameters.sp)
* v_supply_high: the high suppyl voltage in a dual voltage systme.

* ports of the subckt and their functions
* =======================================
* vsp: source for PMOS transistors in the x-coupled inverters
*      usually connected to Vdd or virtual Vdd
* vsn: source for NMOS transistors in the x-coupled inverters
*      usually connected to Gnd or virtual Gnd
* vbp: bulk for the PMOS transistors in the SRAM cell
* vbn: bulk for the NMOS transistors in the SRAM cell
* word: word line to select this cell; it can be used as write-enable
*       or read-enable
* bit:  data bit line (write/read)
* nbit: data-bar bit line (write/read)


.subckt C_pref0_data0_EH vsp vbp vsn vbn word bit nbit

*For 0.10um technology, l= 2*lmda = 0.10um
**eg. .param lmda=0.05u (this parameter will be set in file parameters.sp)

*m1 data ndata vsp vbp PMOS_H l='2*lmda' w='4*lmda' ad='32*lmda*lmda'
*+ as='32*lmda*lmda' pd='24*lmda' ps='24*lmda'
*m2 data ndata vsn vbn NMOS l='2*lmda' w='4.5*lmda' ad='40.5*lmda*lmda'
*+ as='40.5*lmda*lmda' pd='27*lmda' ps='27*lmda'
*m3 ndata data vsp vbp PMOS l='2*lmda' w='4*lmda' ad='32*lmda*lmda'
*+ as='32*lmda*lmda' pd='24*lmda' ps='24*lmda'
*m4 ndata data vsn vbn NMOS_H l='2*lmda' w='4.5*lmda' ad='40.5*lmda*lmda'
*+ as='40.5*lmda*lmda' pd='27*lmda' ps='27*lmda'
*m5 bit word data vbn NMOS_H l='2.75*lmda' w='3.5*lmda' ad='24.5*lmda*lmda'
*+ as='24.5*lmda*lmda' pd='21*lmda' ps='21*lmda'
*m6 nbit word ndata vbn NMOS l='2.75*lmda' w='3.5*lmda' ad='24.5*lmda*lmda'
*+ as='24.5*lmda*lmda' pd='21*lmda' ps='21*lmda'

m1 data ndata vsp vbp PMOS_EH l='2*lmda' w='8.0*lmda' ad='32*lmda*lmda'
+ as='32*lmda*lmda' pd='24*lmda' ps='24*lmda'
m2 data ndata vsn vbn NMOS l='2*lmda' w='8.5*lmda' ad='40.5*lmda*lmda'
+ as='40.5*lmda*lmda' pd='27*lmda' ps='27*lmda'
m3 ndata data vsp vbp PMOS l='2*lmda' w='8.0*lmda' ad='32*lmda*lmda'
+ as='32*lmda*lmda' pd='24*lmda' ps='24*lmda'
m4 ndata data vsn vbn NMOS_EH l='2*lmda' w='8.5*lmda' ad='40.5*lmda*lmda'
+ as='40.5*lmda*lmda' pd='27*lmda' ps='27*lmda'
m5 bit word data vbn NMOS_EH l='2.75*lmda' w='3.5*lmda' ad='24.5*lmda*lmda'
+ as='24.5*lmda*lmda' pd='21*lmda' ps='21*lmda'
m6 nbit word ndata vbn NMOS l='2.75*lmda' w='3.5*lmda' ad='24.5*lmda*lmda'
+ as='24.5*lmda*lmda' pd='21*lmda' ps='21*lmda'

*Initialize node voltages (CHANGE FOR 0.07um)
.nodeset v(data)=0
.nodeset v(ndata)=v_supply

* use this typical value for each segment or connect to a gate?
*cbit bit 0 0.316442f
*cnbit nbit 0 0.316442f

.ends C_pref0_data0_EH

*(13)
* parameters
* =================
* lmda: design rule parameters (set in the file parameters.sp)
* v_supply: supply votage (set in the file parameters.sp)
* v_supply_high: the high suppyl voltage in a dual voltage systme.

* ports of the subckt and their functions
* =======================================
* vsp: source for PMOS transistors in the x-coupled inverters
*      usually connected to Vdd or virtual Vdd
* vbp: bulk for the PMOS transistors in the SRAM cell
* vsn: source for NMOS transistors in the x-coupled inverters
*      usually connected to Gnd or virtual Gnd
* vbn: bulk for the NMOS transistors in the SRAM cell
* word: word line to select this cell; it can be used as write-enable
*       or read-enable
* bit:  data bit line (write/read)
* nbit: data-bar bit line (write/read)


.subckt C_data1_EH vsp vbp vsn vbn word bit nbit

*For 0.10um technology, l= 2*lmda = 0.10um
**eg. .param lmda=0.05u (this parameter will be set in file parameters.sp)

*m1 data ndata vsp vbp PMOS_H l='2*lmda' w='4*lmda' ad='32*lmda*lmda'
*+ as='32*lmda*lmda' pd='24*lmda' ps='24*lmda'
*m2 data ndata vsn vbn NMOS_H l='2*lmda' w='4.5*lmda' ad='40.5*lmda*lmda'
*+ as='40.5*lmda*lmda' pd='27*lmda' ps='27*lmda'
*m3 ndata data vsp vbp PMOS_H l='2*lmda' w='4*lmda' ad='32*lmda*lmda'
*+ as='32*lmda*lmda' pd='24*lmda' ps='24*lmda'
*m4 ndata data vsn vbn NMOS_H l='2*lmda' w='4.5*lmda' ad='40.5*lmda*lmda'
*+ as='40.5*lmda*lmda' pd='27*lmda' ps='27*lmda'
*m5 bit word data vbn NMOS_H l='2.75*lmda' w='3.5*lmda' ad='24.5*lmda*lmda'
*+ as='24.5*lmda*lmda' pd='21*lmda' ps='21*lmda'
*m6 nbit word ndata vbn NMOS_H l='2.75*lmda' w='3.5*lmda' ad='24.5*lmda*lmda'
*+ as='24.5*lmda*lmda' pd='21*lmda' ps='21*lmda'

m1 data ndata vsp vbp PMOS_EH l='2*lmda' w='6.5*lmda' ad='32*lmda*lmda'
+ as='32*lmda*lmda' pd='24*lmda' ps='24*lmda'
m2 data ndata vsn vbn NMOS_EH l='2*lmda' w='7.5*lmda' ad='40.5*lmda*lmda'
+ as='40.5*lmda*lmda' pd='27*lmda' ps='27*lmda'
m3 ndata data vsp vbp PMOS_EH l='2*lmda' w='6.5*lmda' ad='32*lmda*lmda'
+ as='32*lmda*lmda' pd='24*lmda' ps='24*lmda'
m4 ndata data vsn vbn NMOS_EH l='2*lmda' w='7.5*lmda' ad='40.5*lmda*lmda'
+ as='40.5*lmda*lmda' pd='27*lmda' ps='27*lmda'
m5 bit word data vbn NMOS_EH l='2.75*lmda' w='3.5*lmda' ad='24.5*lmda*lmda'
+ as='24.5*lmda*lmda' pd='21*lmda' ps='21*lmda'
m6 nbit word ndata vbn NMOS_EH l='2.75*lmda' w='3.5*lmda' ad='24.5*lmda*lmda'
+ as='24.5*lmda*lmda' pd='21*lmda' ps='21*lmda'

*Initialize node voltages (CHANGE FOR 0.07um)
.nodeset v(data)=v_supply
.nodeset v(ndata)=0

* use this typical value for each segment or connect to a gate?
*cbit bit 0 0.316442f
*cnbit nbit 0 0.316442f

.ends C_data1_EH


*(14)
* parameters
* =================
* lmda: design rule parameters (set in the file parameters.sp)
* v_supply: supply votage (set in the file parameters.sp)
* v_supply_high: the high suppyl voltage in a dual voltage systme.

* ports of the subckt and their functions
* =======================================
* vsp: source for PMOS transistors in the x-coupled inverters
*      usually connected to Vdd or virtual Vdd
* vsn: source for NMOS transistors in the x-coupled inverters
*      usually connected to Gnd or virtual Gnd
* vbp: bulk for the PMOS transistors in the SRAM cell
* vbn: bulk for the NMOS transistors in the SRAM cell
* word: word line to select this cell; it can be used as write-enable
*       or read-enable
* bit:  data bit line (write/read)
* nbit: data-bar bit line (write/read)


.subckt C_data0_EH vsp vbp vsn vbn word bit nbit

*For 0.10um technology, l= 2*lmda = 0.10um
**eg. .param lmda=0.05u (this parameter will be set in file parameters.sp)

*m1 data ndata vsp vbp PMOS_H l='2*lmda' w='4*lmda' ad='32*lmda*lmda'
*+ as='32*lmda*lmda' pd='24*lmda' ps='24*lmda'
*m2 data ndata vsn vbn NMOS_H l='2*lmda' w='4.5*lmda' ad='40.5*lmda*lmda'
*+ as='40.5*lmda*lmda' pd='27*lmda' ps='27*lmda'
*m3 ndata data vsp vbp PMOS_H l='2*lmda' w='4*lmda' ad='32*lmda*lmda'
*+ as='32*lmda*lmda' pd='24*lmda' ps='24*lmda'
*m4 ndata data vsn vbn NMOS_H l='2*lmda' w='4.5*lmda' ad='40.5*lmda*lmda'
*+ as='40.5*lmda*lmda' pd='27*lmda' ps='27*lmda'
*m5 bit word data vbn NMOS_H l='2.75*lmda' w='3.5*lmda' ad='24.5*lmda*lmda'
*+ as='24.5*lmda*lmda' pd='21*lmda' ps='21*lmda'
*m6 nbit word ndata vbn NMOS_H l='2.75*lmda' w='3.5*lmda' ad='24.5*lmda*lmda'
*+ as='24.5*lmda*lmda' pd='21*lmda' ps='21*lmda'

m1 data ndata vsp vbp PMOS_EH l='2*lmda' w='6.5*lmda' ad='32*lmda*lmda'
+ as='32*lmda*lmda' pd='24*lmda' ps='24*lmda'
m2 data ndata vsn vbn NMOS_EH l='2*lmda' w='7.5*lmda' ad='40.5*lmda*lmda'
+ as='40.5*lmda*lmda' pd='27*lmda' ps='27*lmda'
m3 ndata data vsp vbp PMOS_EH l='2*lmda' w='6.5*lmda' ad='32*lmda*lmda'
+ as='32*lmda*lmda' pd='24*lmda' ps='24*lmda'
m4 ndata data vsn vbn NMOS_EH l='2*lmda' w='7.5*lmda' ad='40.5*lmda*lmda'
+ as='40.5*lmda*lmda' pd='27*lmda' ps='27*lmda'
m5 bit word data vbn NMOS_EH l='2.75*lmda' w='3.5*lmda' ad='24.5*lmda*lmda'
+ as='24.5*lmda*lmda' pd='21*lmda' ps='21*lmda'
m6 nbit word ndata vbn NMOS_EH l='2.75*lmda' w='3.5*lmda' ad='24.5*lmda*lmda'
+ as='24.5*lmda*lmda' pd='21*lmda' ps='21*lmda'

*Initialize node voltages (CHANGE FOR 0.07um)
.nodeset v(data)=0
.nodeset v(ndata)=v_supply

* use this typical value for each segment or connect to a gate?
*cbit bit 0 0.316442f
*cnbit nbit 0 0.316442f

.ends C_data0_EH

*-----------------------------------------------------------------

*(15)
* parameters
* =================
* lmda: design rule parameters (set in the file parameters.sp)
* v_supply: supply votage (set in the file parameters.sp)
* v_supply_high: the high suppyl voltage in a dual voltage systme.

* ports of the subckt and their functions
* =======================================
* vsp: source for PMOS transistors in the x-coupled inverters
*      usually connected to Vdd or virtual Vdd
* vsn: source for NMOS transistors in the x-coupled inverters
*      usually connected to Gnd or virtual Gnd
* vbp: bulk for the PMOS transistors in the SRAM cell
* vbn: bulk for the NMOS transistors in the SRAM cell
* word: word line to select this cell; it can be used as write-enable
*       or read-enable
* bit:  data bit line (write/read)
* nbit: data-bar bit line (write/read)


.subckt C_pref1_data0_HEH vsp vbp vsn vbn word bit nbit

*For 0.10um technology, l= 2*lmda = 0.10um
**eg. .param lmda=0.05u (this parameter will be set in file parameters.sp)

*m1 data ndata vsp vbp PMOS l='2*lmda' w='4*lmda' ad='32*lmda*lmda'
*+ as='32*lmda*lmda' pd='24*lmda' ps='24*lmda'
*m2 data ndata vsn vbn NMOS_H l='2*lmda' w='4.5*lmda' ad='40.5*lmda*lmda'
*+ as='40.5*lmda*lmda' pd='27*lmda' ps='27*lmda'
*m3 ndata data vsp vbp PMOS_H l='2*lmda' w='4*lmda' ad='32*lmda*lmda'
*+ as='32*lmda*lmda' pd='24*lmda' ps='24*lmda'
*m4 ndata data vsn vbn NMOS l='2*lmda' w='4.5*lmda' ad='40.5*lmda*lmda'
*+ as='40.5*lmda*lmda' pd='27*lmda' ps='27*lmda'
*m5 bit word data vbn NMOS l='2.75*lmda' w='3.5*lmda' ad='24.5*lmda*lmda'
*+ as='24.5*lmda*lmda' pd='21*lmda' ps='21*lmda'
*m6 nbit word ndata vbn NMOS_H l='2.75*lmda' w='3.5*lmda' ad='24.5*lmda*lmda'
*+ as='24.5*lmda*lmda' pd='21*lmda' ps='21*lmda'

m1 data ndata vsp vbp PMOS_H l='2*lmda' w='6.5*lmda' ad='32*lmda*lmda'
+ as='32*lmda*lmda' pd='24*lmda' ps='24*lmda'
m2 data ndata vsn vbn NMOS_EH l='2*lmda' w='7.5*lmda' ad='40.5*lmda*lmda'
+ as='40.5*lmda*lmda' pd='27*lmda' ps='27*lmda'
m3 ndata data vsp vbp PMOS_EH l='2*lmda' w='6.5*lmda' ad='32*lmda*lmda'
+ as='32*lmda*lmda' pd='24*lmda' ps='24*lmda'
m4 ndata data vsn vbn NMOS_H l='2*lmda' w='7.5*lmda' ad='40.5*lmda*lmda'
+ as='40.5*lmda*lmda' pd='27*lmda' ps='27*lmda'
m5 bit word data vbn NMOS_H l='2.75*lmda' w='3.5*lmda' ad='24.5*lmda*lmda'
+ as='24.5*lmda*lmda' pd='21*lmda' ps='21*lmda'
m6 nbit word ndata vbn NMOS_EH l='2.75*lmda' w='3.5*lmda' ad='24.5*lmda*lmda'
+ as='24.5*lmda*lmda' pd='21*lmda' ps='21*lmda'

*Initialize node voltages (CHANGE FOR 0.07um)
.nodeset v(data)=0
.nodeset v(ndata)=v_supply

* use this typical value for each segment or connect to a gate?
*cbit bit 0 0.316442f
*cnbit nbit 0 0.316442f

.ends C_pref1_data0_HEH

*(16)
* parameters
* =================
* lmda: design rule parameters (set in the file parameters.sp)
* v_supply: supply votage (set in the file parameters.sp)
* v_supply_high: the high suppyl voltage in a dual voltage systme.

* ports of the subckt and their functions
* =======================================
* vsp: source for PMOS transistors in the x-coupled inverters
*      usually connected to Vdd or virtual Vdd
* vsn: source for NMOS transistors in the x-coupled inverters
*      usually connected to Gnd or virtual Gnd
* vbp: bulk for the PMOS transistors in the SRAM cell
* vbn: bulk for the NMOS transistors in the SRAM cell
* word: word line to select this cell; it can be used as write-enable
*       or read-enable
* bit:  data bit line (write/read)
* nbit: data-bar bit line (write/read)


.subckt C_pref1_data1_HEH vsp vbp vsn vbn word bit nbit

*For 0.10um technology, l= 2*lmda = 0.10um
**eg. .param lmda=0.05u (this parameter will be set in file parameters.sp)

*m1 data ndata vsp vbp PMOS l='2*lmda' w='4*lmda' ad='32*lmda*lmda'
*+ as='32*lmda*lmda' pd='24*lmda' ps='24*lmda'
*m2 data ndata vsn vbn NMOS_H l='2*lmda' w='4.5*lmda' ad='40.5*lmda*lmda'
*+ as='40.5*lmda*lmda' pd='27*lmda' ps='27*lmda'
*m3 ndata data vsp vbp PMOS_H l='2*lmda' w='4*lmda' ad='32*lmda*lmda'
*+ as='32*lmda*lmda' pd='24*lmda' ps='24*lmda'
*m4 ndata data vsn vbn NMOS l='2*lmda' w='4.5*lmda' ad='40.5*lmda*lmda'
*+ as='40.5*lmda*lmda' pd='27*lmda' ps='27*lmda'
*m5 bit word data vbn NMOS l='2.75*lmda' w='3.5*lmda' ad='24.5*lmda*lmda'
*+ as='24.5*lmda*lmda' pd='21*lmda' ps='21*lmda'
*m6 nbit word ndata vbn NMOS_H l='2.75*lmda' w='3.5*lmda' ad='24.5*lmda*lmda'
*+ as='24.5*lmda*lmda' pd='21*lmda' ps='21*lmda'

m1 data ndata vsp vbp PMOS_H l='2*lmda' w='6.5*lmda' ad='32*lmda*lmda'
+ as='32*lmda*lmda' pd='24*lmda' ps='24*lmda'
m2 data ndata vsn vbn NMOS_EH l='2*lmda' w='7.5*lmda' ad='40.5*lmda*lmda'
+ as='40.5*lmda*lmda' pd='27*lmda' ps='27*lmda'
m3 ndata data vsp vbp PMOS_EH l='2*lmda' w='6.5*lmda' ad='32*lmda*lmda'
+ as='32*lmda*lmda' pd='24*lmda' ps='24*lmda'
m4 ndata data vsn vbn NMOS_H l='2*lmda' w='7.5*lmda' ad='40.5*lmda*lmda'
+ as='40.5*lmda*lmda' pd='27*lmda' ps='27*lmda'
m5 bit word data vbn NMOS_H l='2.75*lmda' w='3.5*lmda' ad='24.5*lmda*lmda'
+ as='24.5*lmda*lmda' pd='21*lmda' ps='21*lmda'
m6 nbit word ndata vbn NMOS_EH l='2.75*lmda' w='3.5*lmda' ad='24.5*lmda*lmda'
+ as='24.5*lmda*lmda' pd='21*lmda' ps='21*lmda'

*Initialize node voltages (CHANGE FOR 0.07um)
.nodeset v(data)=v_supply
.nodeset v(ndata)=0

* use this typical value for each segment or connect to a gate?
*cbit bit 0 0.316442f
*cnbit nbit 0 0.316442f

.ends C_pref1_data1_HEH

*(17)
* parameters
* =================
* lmda: design rule parameters (set in the file parameters.sp)
* v_supply: supply votage (set in the file parameters.sp)
* v_supply_high: the high suppyl voltage in a dual voltage systme.

* ports of the subckt and their functions
* =======================================
* vsp: source for PMOS transistors in the x-coupled inverters
*      usually connected to Vdd or virtual Vdd
* vsn: source for NMOS transistors in the x-coupled inverters
*      usually connected to Gnd or virtual Gnd
* vbp: bulk for the PMOS transistors in the SRAM cell
* vbn: bulk for the NMOS transistors in the SRAM cell
* word: word line to select this cell; it can be used as write-enable
*       or read-enable
* bit:  data bit line (write/read)
* nbit: data-bar bit line (write/read)


.subckt C_pref0_data1_HEH vsp vbp vsn vbn word bit nbit

*For 0.10um technology, l= 2*lmda = 0.10um
**eg. .param lmda=0.05u (this parameter will be set in file parameters.sp)

*m1 data ndata vsp vbp PMOS_H l='2*lmda' w='4*lmda' ad='32*lmda*lmda'
*+ as='32*lmda*lmda' pd='24*lmda' ps='24*lmda'
*m2 data ndata vsn vbn NMOS l='2*lmda' w='4.5*lmda' ad='40.5*lmda*lmda'
*+ as='40.5*lmda*lmda' pd='27*lmda' ps='27*lmda'
*m3 ndata data vsp vbp PMOS l='2*lmda' w='4*lmda' ad='32*lmda*lmda'
*+ as='32*lmda*lmda' pd='24*lmda' ps='24*lmda'
*m4 ndata data vsn vbn NMOS_H l='2*lmda' w='4.5*lmda' ad='40.5*lmda*lmda'
*+ as='40.5*lmda*lmda' pd='27*lmda' ps='27*lmda'
*m5 bit word data vbn NMOS_H l='2.75*lmda' w='3.5*lmda' ad='24.5*lmda*lmda'
*+ as='24.5*lmda*lmda' pd='21*lmda' ps='21*lmda'
*m6 nbit word ndata vbn NMOS l='2.75*lmda' w='3.5*lmda' ad='24.5*lmda*lmda'
*+ as='24.5*lmda*lmda' pd='21*lmda' ps='21*lmda'

m1 data ndata vsp vbp PMOS_EH l='2*lmda' w='6.5*lmda' ad='32*lmda*lmda'
+ as='32*lmda*lmda' pd='24*lmda' ps='24*lmda'
m2 data ndata vsn vbn NMOS_H l='2*lmda' w='7.5*lmda' ad='40.5*lmda*lmda'
+ as='40.5*lmda*lmda' pd='27*lmda' ps='27*lmda'
m3 ndata data vsp vbp PMOS_H l='2*lmda' w='6.5*lmda' ad='32*lmda*lmda'
+ as='32*lmda*lmda' pd='24*lmda' ps='24*lmda'
m4 ndata data vsn vbn NMOS_EH l='2*lmda' w='7.5*lmda' ad='40.5*lmda*lmda'
+ as='40.5*lmda*lmda' pd='27*lmda' ps='27*lmda'
m5 bit word data vbn NMOS_EH l='2.75*lmda' w='3.5*lmda' ad='24.5*lmda*lmda'
+ as='24.5*lmda*lmda' pd='21*lmda' ps='21*lmda'
m6 nbit word ndata vbn NMOS_H l='2.75*lmda' w='3.5*lmda' ad='24.5*lmda*lmda'
+ as='24.5*lmda*lmda' pd='21*lmda' ps='21*lmda'

*Initialize node voltages (CHANGE FOR 0.07um)
.nodeset v(data)=v_supply
.nodeset v(ndata)=0

* use this typical value for each segment or connect to a gate?
*cbit bit 0 0.316442f
*cnbit nbit 0 0.316442f

.ends C_pref0_data1_HEH

*(18)
* parameters
* =================
* lmda: design rule parameters (set in the file parameters.sp)
* v_supply: supply votage (set in the file parameters.sp)
* v_supply_high: the high suppyl voltage in a dual voltage systme.

* ports of the subckt and their functions
* =======================================
* vsp: source for PMOS transistors in the x-coupled inverters
*      usually connected to Vdd or virtual Vdd
* vsn: source for NMOS transistors in the x-coupled inverters
*      usually connected to Gnd or virtual Gnd
* vbp: bulk for the PMOS transistors in the SRAM cell
* vbn: bulk for the NMOS transistors in the SRAM cell
* word: word line to select this cell; it can be used as write-enable
*       or read-enable
* bit:  data bit line (write/read)
* nbit: data-bar bit line (write/read)


.subckt C_pref0_data0_HEH vsp vbp vsn vbn word bit nbit

*For 0.10um technology, l= 2*lmda = 0.10um
**eg. .param lmda=0.05u (this parameter will be set in file parameters.sp)

*m1 data ndata vsp vbp PMOS_H l='2*lmda' w='4*lmda' ad='32*lmda*lmda'
*+ as='32*lmda*lmda' pd='24*lmda' ps='24*lmda'
*m2 data ndata vsn vbn NMOS l='2*lmda' w='4.5*lmda' ad='40.5*lmda*lmda'
*+ as='40.5*lmda*lmda' pd='27*lmda' ps='27*lmda'
*m3 ndata data vsp vbp PMOS l='2*lmda' w='4*lmda' ad='32*lmda*lmda'
*+ as='32*lmda*lmda' pd='24*lmda' ps='24*lmda'
*m4 ndata data vsn vbn NMOS_H l='2*lmda' w='4.5*lmda' ad='40.5*lmda*lmda'
*+ as='40.5*lmda*lmda' pd='27*lmda' ps='27*lmda'
*m5 bit word data vbn NMOS_H l='2.75*lmda' w='3.5*lmda' ad='24.5*lmda*lmda'
*+ as='24.5*lmda*lmda' pd='21*lmda' ps='21*lmda'
*m6 nbit word ndata vbn NMOS l='2.75*lmda' w='3.5*lmda' ad='24.5*lmda*lmda'
*+ as='24.5*lmda*lmda' pd='21*lmda' ps='21*lmda'

m1 data ndata vsp vbp PMOS_EH l='2*lmda' w='6.5*lmda' ad='32*lmda*lmda'
+ as='32*lmda*lmda' pd='24*lmda' ps='24*lmda'
m2 data ndata vsn vbn NMOS_H l='2*lmda' w='7.5*lmda' ad='40.5*lmda*lmda'
+ as='40.5*lmda*lmda' pd='27*lmda' ps='27*lmda'
m3 ndata data vsp vbp PMOS_H l='2*lmda' w='6.5*lmda' ad='32*lmda*lmda'
+ as='32*lmda*lmda' pd='24*lmda' ps='24*lmda'
m4 ndata data vsn vbn NMOS_EH l='2*lmda' w='7.5*lmda' ad='40.5*lmda*lmda'
+ as='40.5*lmda*lmda' pd='27*lmda' ps='27*lmda'
m5 bit word data vbn NMOS_EH l='2.75*lmda' w='3.5*lmda' ad='24.5*lmda*lmda'
+ as='24.5*lmda*lmda' pd='21*lmda' ps='21*lmda'
m6 nbit word ndata vbn NMOS_H l='2.75*lmda' w='3.5*lmda' ad='24.5*lmda*lmda'
+ as='24.5*lmda*lmda' pd='21*lmda' ps='21*lmda'

*Initialize node voltages (CHANGE FOR 0.07um)
.nodeset v(data)=0
.nodeset v(ndata)=v_supply

* use this typical value for each segment or connect to a gate?
*cbit bit 0 0.316442f
*cnbit nbit 0 0.316442f

.ends C_pref0_data0_HEH

* ---------------------------------------------------------------------
*----------------------------------------------------------------------
* For low Vdd = 1.0v (Vt scaled w.r.t. Vdd)

.subckt C_data1_VDDL10 vsp vbp vsn vbn word bit nbit

*For 0.10um technology, l= 2*lmda = 0.10um
**eg. .param lmda=0.05u (this parameter will be set in file parameters.sp)

*m1 data ndata vsp vbp PMOS_VDDL10 l='2*lmda' w='4*lmda' ad='32*lmda*lmda'
*+ as='32*lmda*lmda' pd='24*lmda' ps='24*lmda'
*m2 data ndata vsn vbn NMOS_VDDL10 l='2*lmda' w='4.5*lmda' ad='40.5*lmda*lmda'
*+ as='40.5*lmda*lmda' pd='27*lmda' ps='27*lmda'
*m3 ndata data vsp vbp PMOS_VDDL10 l='2*lmda' w='4*lmda' ad='32*lmda*lmda'
*+ as='32*lmda*lmda' pd='24*lmda' ps='24*lmda'
*m4 ndata data vsn vbn NMOS_VDDL10 l='2*lmda' w='4.5*lmda' ad='40.5*lmda*lmda'
*+ as='40.5*lmda*lmda' pd='27*lmda' ps='27*lmda'
*m5 bit word data vbn NMOS_VDDL10 l='2.75*lmda' w='3.5*lmda' ad='24.5*lmda*lmda'
*+ as='24.5*lmda*lmda' pd='21*lmda' ps='21*lmda'
*m6 nbit word ndata vbn NMOS_VDDL10 l='2.75*lmda' w='3.5*lmda' ad='24.5*lmda*lmda'
*+ as='24.5*lmda*lmda' pd='21*lmda' ps='21*lmda'

m1 data ndata vsp vbp PMOS_VDDL10 l='2*lmda' w='6.5*lmda' ad='32*lmda*lmda'
+ as='32*lmda*lmda' pd='24*lmda' ps='24*lmda'
m2 data ndata vsn vbn NMOS_VDDL10 l='2*lmda' w='7.5*lmda' ad='40.5*lmda*lmda'
+ as='40.5*lmda*lmda' pd='27*lmda' ps='27*lmda'
m3 ndata data vsp vbp PMOS_VDDL10 l='2*lmda' w='6.5*lmda' ad='32*lmda*lmda'
+ as='32*lmda*lmda' pd='24*lmda' ps='24*lmda'
m4 ndata data vsn vbn NMOS_VDDL10 l='2*lmda' w='7.5*lmda' ad='40.5*lmda*lmda'
+ as='40.5*lmda*lmda' pd='27*lmda' ps='27*lmda'
m5 bit word data vbn NMOS_VDDL10 l='2.75*lmda' w='3.5*lmda' ad='24.5*lmda*lmda'
+ as='24.5*lmda*lmda' pd='21*lmda' ps='21*lmda'
m6 nbit word ndata vbn NMOS_VDDL10 l='2.75*lmda' w='3.5*lmda' ad='24.5*lmda*lmda'
+ as='24.5*lmda*lmda' pd='21*lmda' ps='21*lmda'

*Initialize node voltages (CHANGE FOR 0.07um)
.nodeset v(data)=v_supply_low10
.nodeset v(ndata)=0

* use this typical value for each segment or connect to a gate?
*cbit bit 0 0.316442f
*cnbit nbit 0 0.316442f

.ends C_data1_VDDL10


*^
.subckt C_data0_VDDL10 vsp vbp vsn vbn word bit nbit

*For 0.10um technology, l= 2*lmda = 0.10um
**eg. .param lmda=0.05u (this parameter will be set in file parameters.sp)

*m1 data ndata vsp vbp PMOS_VDDL10 l='2*lmda' w='4*lmda' ad='32*lmda*lmda'
*+ as='32*lmda*lmda' pd='24*lmda' ps='24*lmda'
*m2 data ndata vsn vbn NMOS_VDDL10 l='2*lmda' w='4.5*lmda' ad='40.5*lmda*lmda'
*+ as='40.5*lmda*lmda' pd='27*lmda' ps='27*lmda'
*m3 ndata data vsp vbp PMOS_VDDL10 l='2*lmda' w='4*lmda' ad='32*lmda*lmda'
*+ as='32*lmda*lmda' pd='24*lmda' ps='24*lmda'
*m4 ndata data vsn vbn NMOS_VDDL10 l='2*lmda' w='4.5*lmda' ad='40.5*lmda*lmda'
*+ as='40.5*lmda*lmda' pd='27*lmda' ps='27*lmda'
*m5 bit word data vbn NMOS_VDDL10 l='2.75*lmda' w='3.5*lmda' ad='24.5*lmda*lmda'
*+ as='24.5*lmda*lmda' pd='21*lmda' ps='21*lmda'
*m6 nbit word ndata vbn NMOS_VDDL10 l='2.75*lmda' w='3.5*lmda' ad='24.5*lmda*lmda'
*+ as='24.5*lmda*lmda' pd='21*lmda' ps='21*lmda'

m1 data ndata vsp vbp PMOS_VDDL10 l='2*lmda' w='6.5*lmda' ad='32*lmda*lmda'
+ as='32*lmda*lmda' pd='24*lmda' ps='24*lmda'
m2 data ndata vsn vbn NMOS_VDDL10 l='2*lmda' w='7.5*lmda' ad='40.5*lmda*lmda'
+ as='40.5*lmda*lmda' pd='27*lmda' ps='27*lmda'
m3 ndata data vsp vbp PMOS_VDDL10 l='2*lmda' w='6.5*lmda' ad='32*lmda*lmda'
+ as='32*lmda*lmda' pd='24*lmda' ps='24*lmda'
m4 ndata data vsn vbn NMOS_VDDL10 l='2*lmda' w='7.5*lmda' ad='40.5*lmda*lmda'
+ as='40.5*lmda*lmda' pd='27*lmda' ps='27*lmda'
m5 bit word data vbn NMOS_VDDL10 l='2.75*lmda' w='3.5*lmda' ad='24.5*lmda*lmda'
+ as='24.5*lmda*lmda' pd='21*lmda' ps='21*lmda'
m6 nbit word ndata vbn NMOS_VDDL10 l='2.75*lmda' w='3.5*lmda' ad='24.5*lmda*lmda'
+ as='24.5*lmda*lmda' pd='21*lmda' ps='21*lmda'

*Initialize node voltages (CHANGE FOR 0.07um)
.nodeset v(data)=0
.nodeset v(ndata)=v_supply_low10

* use this typical value for each segment or connect to a gate?
*cbit bit 0 0.316442f
*cnbit nbit 0 0.316442f

.ends C_data0_VDDL10


* ------
* For low Vdd = 0.9v (Vt scaled w.r.t. Vdd)

.subckt C_data1_VDDL09 vsp vbp vsn vbn word bit nbit

*For 0.10um technology, l= 2*lmda = 0.10um
**eg. .param lmda=0.05u (this parameter will be set in file parameters.sp)

*m1 data ndata vsp vbp PMOS_VDDL09 l='2*lmda' w='4*lmda' ad='32*lmda*lmda'
*+ as='32*lmda*lmda' pd='24*lmda' ps='24*lmda'
*m2 data ndata vsn vbn NMOS_VDDL09 l='2*lmda' w='4.5*lmda' ad='40.5*lmda*lmda'
*+ as='40.5*lmda*lmda' pd='27*lmda' ps='27*lmda'
*m3 ndata data vsp vbp PMOS_VDDL09 l='2*lmda' w='4*lmda' ad='32*lmda*lmda'
*+ as='32*lmda*lmda' pd='24*lmda' ps='24*lmda'
*m4 ndata data vsn vbn NMOS_VDDL09 l='2*lmda' w='4.5*lmda' ad='40.5*lmda*lmda'
*+ as='40.5*lmda*lmda' pd='27*lmda' ps='27*lmda'
*m5 bit word data vbn NMOS_VDDL09 l='2.75*lmda' w='3.5*lmda' ad='24.5*lmda*lmda'
*+ as='24.5*lmda*lmda' pd='21*lmda' ps='21*lmda'
*m6 nbit word ndata vbn NMOS_VDDL09 l='2.75*lmda' w='3.5*lmda' ad='24.5*lmda*lmda'
*+ as='24.5*lmda*lmda' pd='21*lmda' ps='21*lmda'

m1 data ndata vsp vbp PMOS_VDDL09 l='2*lmda' w='6.5*lmda' ad='32*lmda*lmda'
+ as='32*lmda*lmda' pd='24*lmda' ps='24*lmda'
m2 data ndata vsn vbn NMOS_VDDL09 l='2*lmda' w='7.5*lmda' ad='40.5*lmda*lmda'
+ as='40.5*lmda*lmda' pd='27*lmda' ps='27*lmda'
m3 ndata data vsp vbp PMOS_VDDL09 l='2*lmda' w='6.5*lmda' ad='32*lmda*lmda'
+ as='32*lmda*lmda' pd='24*lmda' ps='24*lmda'
m4 ndata data vsn vbn NMOS_VDDL09 l='2*lmda' w='7.5*lmda' ad='40.5*lmda*lmda'
+ as='40.5*lmda*lmda' pd='27*lmda' ps='27*lmda'
m5 bit word data vbn NMOS_VDDL09 l='2.75*lmda' w='3.5*lmda' ad='24.5*lmda*lmda'
+ as='24.5*lmda*lmda' pd='21*lmda' ps='21*lmda'
m6 nbit word ndata vbn NMOS_VDDL09 l='2.75*lmda' w='3.5*lmda' ad='24.5*lmda*lmda'
+ as='24.5*lmda*lmda' pd='21*lmda' ps='21*lmda'

*Initialize node voltages (CHANGE FOR 0.07um)
.nodeset v(data)=v_supply_low09
.nodeset v(ndata)=0

* use this typical value for each segment or connect to a gate?
*cbit bit 0 0.316442f
*cnbit nbit 0 0.316442f

.ends C_data1_VDDL09


*^
.subckt C_data0_VDDL09 vsp vbp vsn vbn word bit nbit

*For 0.10um technology, l= 2*lmda = 0.10um
**eg. .param lmda=0.05u (this parameter will be set in file parameters.sp)

*m1 data ndata vsp vbp PMOS_VDDL09 l='2*lmda' w='4*lmda' ad='32*lmda*lmda'
*+ as='32*lmda*lmda' pd='24*lmda' ps='24*lmda'
*m2 data ndata vsn vbn NMOS_VDDL09 l='2*lmda' w='4.5*lmda' ad='40.5*lmda*lmda'
*+ as='40.5*lmda*lmda' pd='27*lmda' ps='27*lmda'
*m3 ndata data vsp vbp PMOS_VDDL09 l='2*lmda' w='4*lmda' ad='32*lmda*lmda'
*+ as='32*lmda*lmda' pd='24*lmda' ps='24*lmda'
*m4 ndata data vsn vbn NMOS_VDDL09 l='2*lmda' w='4.5*lmda' ad='40.5*lmda*lmda'
*+ as='40.5*lmda*lmda' pd='27*lmda' ps='27*lmda'
*m5 bit word data vbn NMOS_VDDL09 l='2.75*lmda' w='3.5*lmda' ad='24.5*lmda*lmda'
*+ as='24.5*lmda*lmda' pd='21*lmda' ps='21*lmda'
*m6 nbit word ndata vbn NMOS_VDDL09 l='2.75*lmda' w='3.5*lmda' ad='24.5*lmda*lmda'
*+ as='24.5*lmda*lmda' pd='21*lmda' ps='21*lmda'

m1 data ndata vsp vbp PMOS_VDDL09 l='2*lmda' w='6.5*lmda' ad='32*lmda*lmda'
+ as='32*lmda*lmda' pd='24*lmda' ps='24*lmda'
m2 data ndata vsn vbn NMOS_VDDL09 l='2*lmda' w='7.5*lmda' ad='40.5*lmda*lmda'
+ as='40.5*lmda*lmda' pd='27*lmda' ps='27*lmda'
m3 ndata data vsp vbp PMOS_VDDL09 l='2*lmda' w='6.5*lmda' ad='32*lmda*lmda'
+ as='32*lmda*lmda' pd='24*lmda' ps='24*lmda'
m4 ndata data vsn vbn NMOS_VDDL09 l='2*lmda' w='7.5*lmda' ad='40.5*lmda*lmda'
+ as='40.5*lmda*lmda' pd='27*lmda' ps='27*lmda'
m5 bit word data vbn NMOS_VDDL09 l='2.75*lmda' w='3.5*lmda' ad='24.5*lmda*lmda'
+ as='24.5*lmda*lmda' pd='21*lmda' ps='21*lmda'
m6 nbit word ndata vbn NMOS_VDDL09 l='2.75*lmda' w='3.5*lmda' ad='24.5*lmda*lmda'
+ as='24.5*lmda*lmda' pd='21*lmda' ps='21*lmda'

*Initialize node voltages (CHANGE FOR 0.07um)
.nodeset v(data)=0
.nodeset v(ndata)=v_supply_low09

* use this typical value for each segment or connect to a gate?
*cbit bit 0 0.316442f
*cnbit nbit 0 0.316442f

.ends C_data0_VDDL09



* ------
* For low Vdd = 0.8v (Vt scaled w.r.t. Vdd)

.subckt C_data1_VDDL08 vsp vbp vsn vbn word bit nbit

*For 0.10um technology, l= 2*lmda = 0.10um
**eg. .param lmda=0.05u (this parameter will be set in file parameters.sp)

*m1 data ndata vsp vbp PMOS_VDDL08 l='2*lmda' w='4*lmda' ad='32*lmda*lmda'
*+ as='32*lmda*lmda' pd='24*lmda' ps='24*lmda'
*m2 data ndata vsn vbn NMOS_VDDL08 l='2*lmda' w='4.5*lmda' ad='40.5*lmda*lmda'
*+ as='40.5*lmda*lmda' pd='27*lmda' ps='27*lmda'
*m3 ndata data vsp vbp PMOS_VDDL08 l='2*lmda' w='4*lmda' ad='32*lmda*lmda'
*+ as='32*lmda*lmda' pd='24*lmda' ps='24*lmda'
*m4 ndata data vsn vbn NMOS_VDDL08 l='2*lmda' w='4.5*lmda' ad='40.5*lmda*lmda'
*+ as='40.5*lmda*lmda' pd='27*lmda' ps='27*lmda'
*m5 bit word data vbn NMOS_VDDL08 l='2.75*lmda' w='3.5*lmda' ad='24.5*lmda*lmda'
*+ as='24.5*lmda*lmda' pd='21*lmda' ps='21*lmda'
*m6 nbit word ndata vbn NMOS_VDDL08 l='2.75*lmda' w='3.5*lmda' ad='24.5*lmda*lmda'
*+ as='24.5*lmda*lmda' pd='21*lmda' ps='21*lmda'

m1 data ndata vsp vbp PMOS_VDDL08 l='2*lmda' w='6.5*lmda' ad='32*lmda*lmda'
+ as='32*lmda*lmda' pd='24*lmda' ps='24*lmda'
m2 data ndata vsn vbn NMOS_VDDL08 l='2*lmda' w='7.5*lmda' ad='40.5*lmda*lmda'
+ as='40.5*lmda*lmda' pd='27*lmda' ps='27*lmda'
m3 ndata data vsp vbp PMOS_VDDL08 l='2*lmda' w='6.5*lmda' ad='32*lmda*lmda'
+ as='32*lmda*lmda' pd='24*lmda' ps='24*lmda'
m4 ndata data vsn vbn NMOS_VDDL08 l='2*lmda' w='7.5*lmda' ad='40.5*lmda*lmda'
+ as='40.5*lmda*lmda' pd='27*lmda' ps='27*lmda'
m5 bit word data vbn NMOS_VDDL08 l='2.75*lmda' w='3.5*lmda' ad='24.5*lmda*lmda'
+ as='24.5*lmda*lmda' pd='21*lmda' ps='21*lmda'
m6 nbit word ndata vbn NMOS_VDDL08 l='2.75*lmda' w='3.5*lmda' ad='24.5*lmda*lmda'
+ as='24.5*lmda*lmda' pd='21*lmda' ps='21*lmda'

*Initialize node voltages (CHANGE FOR 0.07um)
.nodeset v(data)=v_supply_low08
.nodeset v(ndata)=0

* use this typical value for each segment or connect to a gate?
*cbit bit 0 0.316442f
*cnbit nbit 0 0.316442f

.ends C_data1_VDDL08


*^
.subckt C_data0_VDDL08 vsp vbp vsn vbn word bit nbit

*For 0.10um technology, l= 2*lmda = 0.10um
**eg. .param lmda=0.05u (this parameter will be set in file parameters.sp)

*m1 data ndata vsp vbp PMOS_VDDL08 l='2*lmda' w='4*lmda' ad='32*lmda*lmda'
*+ as='32*lmda*lmda' pd='24*lmda' ps='24*lmda'
*m2 data ndata vsn vbn NMOS_VDDL08 l='2*lmda' w='4.5*lmda' ad='40.5*lmda*lmda'
*+ as='40.5*lmda*lmda' pd='27*lmda' ps='27*lmda'
*m3 ndata data vsp vbp PMOS_VDDL08 l='2*lmda' w='4*lmda' ad='32*lmda*lmda'
*+ as='32*lmda*lmda' pd='24*lmda' ps='24*lmda'
*m4 ndata data vsn vbn NMOS_VDDL08 l='2*lmda' w='4.5*lmda' ad='40.5*lmda*lmda'
*+ as='40.5*lmda*lmda' pd='27*lmda' ps='27*lmda'
*m5 bit word data vbn NMOS_VDDL08 l='2.75*lmda' w='3.5*lmda' ad='24.5*lmda*lmda'
*+ as='24.5*lmda*lmda' pd='21*lmda' ps='21*lmda'
*m6 nbit word ndata vbn NMOS_VDDL08 l='2.75*lmda' w='3.5*lmda' ad='24.5*lmda*lmda'
*+ as='24.5*lmda*lmda' pd='21*lmda' ps='21*lmda'

m1 data ndata vsp vbp PMOS_VDDL08 l='2*lmda' w='6.5*lmda' ad='32*lmda*lmda'
+ as='32*lmda*lmda' pd='24*lmda' ps='24*lmda'
m2 data ndata vsn vbn NMOS_VDDL08 l='2*lmda' w='7.5*lmda' ad='40.5*lmda*lmda'
+ as='40.5*lmda*lmda' pd='27*lmda' ps='27*lmda'
m3 ndata data vsp vbp PMOS_VDDL08 l='2*lmda' w='6.5*lmda' ad='32*lmda*lmda'
+ as='32*lmda*lmda' pd='24*lmda' ps='24*lmda'
m4 ndata data vsn vbn NMOS_VDDL08 l='2*lmda' w='7.5*lmda' ad='40.5*lmda*lmda'
+ as='40.5*lmda*lmda' pd='27*lmda' ps='27*lmda'
m5 bit word data vbn NMOS_VDDL08 l='2.75*lmda' w='3.5*lmda' ad='24.5*lmda*lmda'
+ as='24.5*lmda*lmda' pd='21*lmda' ps='21*lmda'
m6 nbit word ndata vbn NMOS_VDDL08 l='2.75*lmda' w='3.5*lmda' ad='24.5*lmda*lmda'
+ as='24.5*lmda*lmda' pd='21*lmda' ps='21*lmda'

*Initialize node voltages (CHANGE FOR 0.07um)
.nodeset v(data)=0
.nodeset v(ndata)=v_supply_low08

* use this typical value for each segment or connect to a gate?
*cbit bit 0 0.316442f
*cnbit nbit 0 0.316442f

.ends C_data0_VDDL08



* ------
* For low Vdd = 0.7v (Vt scaled w.r.t. Vdd)

.subckt C_data1_VDDL07 vsp vbp vsn vbn word bit nbit

*For 0.10um technology, l= 2*lmda = 0.10um
**eg. .param lmda=0.05u (this parameter will be set in file parameters.sp)

*m1 data ndata vsp vbp PMOS_VDDL07 l='2*lmda' w='4*lmda' ad='32*lmda*lmda'
*+ as='32*lmda*lmda' pd='24*lmda' ps='24*lmda'
*m2 data ndata vsn vbn NMOS_VDDL07 l='2*lmda' w='4.5*lmda' ad='40.5*lmda*lmda'
*+ as='40.5*lmda*lmda' pd='27*lmda' ps='27*lmda'
*m3 ndata data vsp vbp PMOS_VDDL07 l='2*lmda' w='4*lmda' ad='32*lmda*lmda'
*+ as='32*lmda*lmda' pd='24*lmda' ps='24*lmda'
*m4 ndata data vsn vbn NMOS_VDDL07 l='2*lmda' w='4.5*lmda' ad='40.5*lmda*lmda'
*+ as='40.5*lmda*lmda' pd='27*lmda' ps='27*lmda'
*m5 bit word data vbn NMOS_VDDL07 l='2.75*lmda' w='3.5*lmda' ad='24.5*lmda*lmda'
*+ as='24.5*lmda*lmda' pd='21*lmda' ps='21*lmda'
*m6 nbit word ndata vbn NMOS_VDDL07 l='2.75*lmda' w='3.5*lmda' ad='24.5*lmda*lmda'
*+ as='24.5*lmda*lmda' pd='21*lmda' ps='21*lmda'

m1 data ndata vsp vbp PMOS_VDDL07 l='2*lmda' w='6.5*lmda' ad='32*lmda*lmda'
+ as='32*lmda*lmda' pd='24*lmda' ps='24*lmda'
m2 data ndata vsn vbn NMOS_VDDL07 l='2*lmda' w='7.5*lmda' ad='40.5*lmda*lmda'
+ as='40.5*lmda*lmda' pd='27*lmda' ps='27*lmda'
m3 ndata data vsp vbp PMOS_VDDL07 l='2*lmda' w='6.5*lmda' ad='32*lmda*lmda'
+ as='32*lmda*lmda' pd='24*lmda' ps='24*lmda'
m4 ndata data vsn vbn NMOS_VDDL07 l='2*lmda' w='7.5*lmda' ad='40.5*lmda*lmda'
+ as='40.5*lmda*lmda' pd='27*lmda' ps='27*lmda'
m5 bit word data vbn NMOS_VDDL07 l='2.75*lmda' w='3.5*lmda' ad='24.5*lmda*lmda'
+ as='24.5*lmda*lmda' pd='21*lmda' ps='21*lmda'
m6 nbit word ndata vbn NMOS_VDDL07 l='2.75*lmda' w='3.5*lmda' ad='24.5*lmda*lmda'
+ as='24.5*lmda*lmda' pd='21*lmda' ps='21*lmda'

*Initialize node voltages (CHANGE FOR 0.07um)
.nodeset v(data)=v_supply_low07
.nodeset v(ndata)=0

* use this typical value for each segment or connect to a gate?
*cbit bit 0 0.316442f
*cnbit nbit 0 0.316442f

.ends C_data1_VDDL07


*^
.subckt C_data0_VDDL07 vsp vbp vsn vbn word bit nbit

*For 0.10um technology, l= 2*lmda = 0.10um
**eg. .param lmda=0.05u (this parameter will be set in file parameters.sp)

*m1 data ndata vsp vbp PMOS_VDDL07 l='2*lmda' w='4*lmda' ad='32*lmda*lmda'
*+ as='32*lmda*lmda' pd='24*lmda' ps='24*lmda'
*m2 data ndata vsn vbn NMOS_VDDL07 l='2*lmda' w='4.5*lmda' ad='40.5*lmda*lmda'
*+ as='40.5*lmda*lmda' pd='27*lmda' ps='27*lmda'
*m3 ndata data vsp vbp PMOS_VDDL07 l='2*lmda' w='4*lmda' ad='32*lmda*lmda'
*+ as='32*lmda*lmda' pd='24*lmda' ps='24*lmda'
*m4 ndata data vsn vbn NMOS_VDDL07 l='2*lmda' w='4.5*lmda' ad='40.5*lmda*lmda'
*+ as='40.5*lmda*lmda' pd='27*lmda' ps='27*lmda'
*m5 bit word data vbn NMOS_VDDL07 l='2.75*lmda' w='3.5*lmda' ad='24.5*lmda*lmda'
*+ as='24.5*lmda*lmda' pd='21*lmda' ps='21*lmda'
*m6 nbit word ndata vbn NMOS_VDDL07 l='2.75*lmda' w='3.5*lmda' ad='24.5*lmda*lmda'
*+ as='24.5*lmda*lmda' pd='21*lmda' ps='21*lmda'

m1 data ndata vsp vbp PMOS_VDDL07 l='2*lmda' w='6.5*lmda' ad='32*lmda*lmda'
+ as='32*lmda*lmda' pd='24*lmda' ps='24*lmda'
m2 data ndata vsn vbn NMOS_VDDL07 l='2*lmda' w='7.5*lmda' ad='40.5*lmda*lmda'
+ as='40.5*lmda*lmda' pd='27*lmda' ps='27*lmda'
m3 ndata data vsp vbp PMOS_VDDL07 l='2*lmda' w='6.5*lmda' ad='32*lmda*lmda'
+ as='32*lmda*lmda' pd='24*lmda' ps='24*lmda'
m4 ndata data vsn vbn NMOS_VDDL07 l='2*lmda' w='7.5*lmda' ad='40.5*lmda*lmda'
+ as='40.5*lmda*lmda' pd='27*lmda' ps='27*lmda'
m5 bit word data vbn NMOS_VDDL07 l='2.75*lmda' w='3.5*lmda' ad='24.5*lmda*lmda'
+ as='24.5*lmda*lmda' pd='21*lmda' ps='21*lmda'
m6 nbit word ndata vbn NMOS_VDDL07 l='2.75*lmda' w='3.5*lmda' ad='24.5*lmda*lmda'
+ as='24.5*lmda*lmda' pd='21*lmda' ps='21*lmda'

*Initialize node voltages (CHANGE FOR 0.07um)
.nodeset v(data)=0
.nodeset v(ndata)=v_supply_low07

* use this typical value for each segment or connect to a gate?
*cbit bit 0 0.316442f
*cnbit nbit 0 0.316442f

.ends C_data0_VDDL07
