*NOR2 NAND2(minimum width)
*scalable lamda design rule

* Fei LI
*07/17/02

* parameters
* =================
* lmda: design rule parameters (set in the file parameters.sp)
* v_supply: supply votage (set in the file parameters.sp)

* ports of the subckt and their functions
* =======================================
* vsp: source for PMOS transistors in the x-coupled inverters
*      usually connected to Vdd or virtual Vdd
* vbp: bulk for the PMOS transistors in the SRAM cell
* vsn: source for NMOS transistors in the x-coupled inverters
*      usually connected to Gnd or virtual Gnd
* vbn: bulk for the NMOS transistors in the SRAM cell
* top_in: the input to the top PMOS transistor
* bot_in: the input to the bottom PMOS transistor
* out:    output


*NOR2 subcircuit definition
.subckt NOR2 vsp vbp vsn vbn top_in bot_in out
*For 0.10um technology, l= 2*lmda = 0.10um
** eg. .param lmda=0.05u

m1 3 top_in vsp vbp PMOS l='2*lmda' w='35*lmda' ad='2450*lmda*lmda'
+ as='2450*lmda*lmda' pd='210*lmda' ps='210*lmda'
m2 out bot_in 3 vbp PMOS l='2*lmda' w='35*lmda' ad='2450*lmda*lmda'
+ as='2450*lmda*lmda' pd='210*lmda' ps='210*lmda'
m3 out top_in vsn vbn NMOS l='2*lmda' w='3.5*lmda' ad='24.5*lmda*lmda'
+ as='24.5*lmda*lmda' pd='21*lmda' ps='21*lmda'
m4 out bot_in vsn vbn NMOS l='2*lmda' w='3.5*lmda' ad='24.5*lmda*lmda'
+ as='24.5*lmda*lmda' pd='21*lmda' ps='21*lmda'
.ends NOR2

*NOR3 subcircuit definition
.subckt NOR3 vsp vbp vsn vbn top_in mid_in bot_in out
*For 0.10um technology, l= 2*lmda = 0.10um
** eg. .param lmda=0.05u

m1 4 top_in vsp vbp PMOS l='2*lmda' w='35*lmda' ad='2450*lmda*lmda'
+ as='2450*lmda*lmda' pd='210*lmda' ps='210*lmda'
m2 out bot_in 3 vbp PMOS l='2*lmda' w='35*lmda' ad='2450*lmda*lmda'
+ as='2450*lmda*lmda' pd='210*lmda' ps='210*lmda'
m0 3 mid_in 4 vbp PMOS l='2*lmda' w='35*lmda' ad='2450*lmda*lmda'
+ as='2450*lmda*lmda' pd='210*lmda' ps='210*lmda'

m3 out top_in vsn vbn NMOS l='2*lmda' w='3.5*lmda' ad='24.5*lmda*lmda'
+ as='24.5*lmda*lmda' pd='21*lmda' ps='21*lmda'
m4 out bot_in vsn vbn NMOS l='2*lmda' w='3.5*lmda' ad='24.5*lmda*lmda'
+ as='24.5*lmda*lmda' pd='21*lmda' ps='21*lmda'
m5 out mid_in vsn vbn NMOS l='2*lmda' w='3.5*lmda' ad='24.5*lmda*lmda'
+ as='24.5*lmda*lmda' pd='21*lmda' ps='21*lmda'
.ends NOR3

*NOR3 subcircuit definition
.subckt NOR3_H vsp vbp vsn vbn top_in mid_in bot_in out
*For 0.10um technology, l= 2*lmda = 0.10um
** eg. .param lmda=0.05u

m1 4 top_in vsp vbp PMOS_H l='2*lmda' w='35*lmda' ad='2450*lmda*lmda'
+ as='2450*lmda*lmda' pd='210*lmda' ps='210*lmda'
m2 out bot_in 3 vbp PMOS_H l='2*lmda' w='35*lmda' ad='2450*lmda*lmda'
+ as='2450*lmda*lmda' pd='210*lmda' ps='210*lmda'
m0 3 mid_in 4 vbp PMOS_H l='2*lmda' w='35*lmda' ad='2450*lmda*lmda'
+ as='2450*lmda*lmda' pd='210*lmda' ps='210*lmda'

m3 out top_in vsn vbn NMOS_H l='2*lmda' w='3.5*lmda' ad='24.5*lmda*lmda'
+ as='24.5*lmda*lmda' pd='21*lmda' ps='21*lmda'
m4 out bot_in vsn vbn NMOS_H l='2*lmda' w='3.5*lmda' ad='24.5*lmda*lmda'
+ as='24.5*lmda*lmda' pd='21*lmda' ps='21*lmda'
m5 out mid_in vsn vbn NMOS_H l='2*lmda' w='3.5*lmda' ad='24.5*lmda*lmda'
+ as='24.5*lmda*lmda' pd='21*lmda' ps='21*lmda'
.ends NOR3_H


.subckt NAND2 vsp vbp vsn vbn top_in bot_in out

m1 out top_in vsp vbp PMOS l='2*lmda' w='8.75*lmda' ad='153.125*lmda*lmda'
+ as='153.125*lmda*lmda' pd='52.5*lmda' ps='52.5*lmda'
m2 out bot_in vsp vbp PMOS l='2*lmda' w='8.75*lmda' ad='153.125*lmda*lmda'
+ as='153.125*lmda*lmda' pd='52.5*lmda' ps='52.5*lmda'
m3 out top_in int_node vbn NMOS  l='2*lmda' w='3.5*lmda' ad='24.5*lmda*lmda'
+ as='24.5*lmda*lmda' pd='21*lmda' ps='21*lmda'
m4 int_node bot_in vsn vbn NMOS  l='2*lmda' w='3.5*lmda' ad='24.5*lmda*lmda'
+ as='24.5*lmda*lmda' pd='21*lmda' ps='21*lmda'

.ends NAND2


.subckt NAND2_H vsp vbp vsn vbn top_in bot_in out

m1 out top_in vsp vbp PMOS_H l='2*lmda' w='8.75*lmda' ad='153.125*lmda*lmda'
+ as='153.125*lmda*lmda' pd='52.5*lmda' ps='52.5*lmda'
m2 out bot_in vsp vbp PMOS_H l='2*lmda' w='8.75*lmda' ad='153.125*lmda*lmda'
+ as='153.125*lmda*lmda' pd='52.5*lmda' ps='52.5*lmda'
m3 out top_in int_node vbn NMOS_H  l='2*lmda' w='3.5*lmda' ad='24.5*lmda*lmda'
+ as='24.5*lmda*lmda' pd='21*lmda' ps='21*lmda'
m4 int_node bot_in vsn vbn NMOS_H  l='2*lmda' w='3.5*lmda' ad='24.5*lmda*lmda'
+ as='24.5*lmda*lmda' pd='21*lmda' ps='21*lmda'

.ends NAND2_H
