*
* This file contains the implementation of PWM and PFM buck circuits. 
*

*
* volt_comp: A voltage comparator from Anthorny J. Stratakos's dissertation.
*            Also reference to the paper "A high-speed CMOS comparator with
*            8-b Resolution".
* inputs: input1, input2 (two inputs to be compared).
* outputs: output (if input1 > input2, output high-level, otherwise, low level). 
* power: vdd, gnd 
* parameters: freq (operation frequency of the control signal)
*
.subckt volt_comp_33 input1 input2 output vdd gnd vc_freq=10e6 vdd_level=3.3 vss_level=0

* first stage
i_bias vdd n1 50u
vbias phi_bias gnd pulse (vss_level vdd_level 0 '0.01/vc_freq' '0.01/vc_freq' '0.99/vc_freq' '2.0/vc_freq')
veq phi_eq gnd pulse (vss_level vdd_level 0 '0.01/vc_freq' '0.01/vc_freq' '0.49/vc_freq' '1.0/vc_freq')
veval phi_eval gnd pulse (vss_level vdd_level '0.64/vc_freq' '0.01/vc_freq' '0.01/vc_freq' '0.34/vc_freq' '1.0/vc_freq')

m_inv1 n2 phi_bias vdd vdd PMOS_VDDL33 L='2*lamda' W='20*lamda'
m_inv2 n2 phi_bias gnd gnd NMOS_VDDL33 L='2*lamda' W='8*lamda'

m3 n3 n2 n1 vdd PMOS_VDDL33 L='2*lamda' W='96*lamda'
m1 ny input1 n3 vdd PMOS_VDDL33 L='5*lamda' W='300*lamda'
m2 nx input2 n3 vdd PMOS_VDDL33 L='5*lamda' W='300*lamda'
m12 nx phi_eq ny gnd NMOS_VDDL33 L='5*lamda' W='4*lamda'
m4 ny nx gnd gnd NMOS_VDDL33 L='2*lamda' W='15*lamda'
m5 nx ny gnd gnd NMOS_VDDL33 L='2*lamda' W='15*lamda'

* second stage
m10 nr phi_eval vdd vdd PMOS_VDDL33 L='2*lamda' W='23*lamda'
m11 ns phi_eval vdd vdd PMOS_VDDL33 L='2*lamda' W='23*lamda'
m8 nr phi_eval nx gnd NMOS_VDDL33 L='2*lamda' W='15*lamda'
m9 ns phi_eval ny gnd NMOS_VDDL33 L='2*lamda' W='15*lamda'
m6 nr ns vdd vdd PMOS_VDDL33 L='2*lamda' W='46*lamda'
m7 ns nr vdd vdd PMOS_VDDL33 L='2*lamda' W='46*lamda'

xrs nr ns output_pre nouse vdd gnd latch_rs_33
xinv output_pre output vdd gnd inv_33 size=5
.ends volt_comp_33

*
* curr_comp: This is a current comparator
*
* inputs: input1, input2 (input1 and input2 are the drain and source of a power transistor)
*         enable (signal to enable the comparator to accept input). 
* outputs: output a pulse to indicate the current becomes 0. 
* parameters: vdd_level, vss_level, freq. 
*
.subckt curr_comp_stage1_33 input1 input2 output1 output2 vdd gnd
ib n1 gnd 50u
i1 vdd output2 10u
i2 vdd output1 10u

mn1 output2 input1 n1 gnd NMOS_VDDL33 L=0.1u W=10u
mn2 output1 input2 n1 gnd NMOS_VDDL33 L=0.1u W=10u
mp1 output2 output2 vdd vdd PMOS_VDDL33 L=0.15u W=0.1u
mp2 output1 output1 vdd vdd PMOS_VDDL33 L=0.15u W=0.1u
cl1 output1 gnd 10f
cl2 output2 gnd 10f
.ends curr_comp_stage1_33

.subckt curr_comp_stage2_33 input1 input2 output1 output2 vdd gnd
ib n1 gnd 30u
i1 vdd output2 10u
i2 vdd output1 10u

mn1 output2 input1 n1 gnd NMOS_VDDL33 L='0.1u' W='10u'
mn2 output1 input2 n1 gnd NMOS_VDDL33 L='0.1u' W='10u'
mp1 output2 output2 vdd vdd PMOS_VDDL33 L='0.15u' W='0.1u'
mp2 output1 output1 vdd vdd PMOS_VDDL33 L='0.15u' W='0.1u'
cl1 output1 gnd 10f
cl2 output2 gnd 10f
.ends curr_comp_stage2_33

.subckt curr_comp_stage3_33 input1 input2 output vdd gnd
ib n1 gnd 10u

mn1 output input2 n1 gnd NMOS_VDDL33 L='0.1u' W='0.8u'
mn2 n2 input1 n1 gnd NMOS_VDDL33 L='0.1u' W='0.8u'
mp1 output n2 vdd vdd PMOS_VDDL33 L='0.1u' W='2.0u'
mp2 n2 n2 vdd vdd PMOS_VDDL33 L='0.1u' W='2.0u'
cl1 output gnd 10f
.ends curr_comp_stage3_33

.subckt curr_comp_nand_33 input1 input2 output vdd gnd
mn1 n1 input1 gnd gnd NMOS_VDDL33 L='2*lamda' W='8*lamda'
mn2 output input2 n1 gnd NMOS_VDDL33 L='2*lamda' W='8*lamda'
mp1 output input1 vdd vdd PMOS_VDDL33 L='2*lamda' W='10*lamda'
mp2 output input2 vdd vdd PMOS_VDDL33 L='2*lamda' W='10*lamda'
.ends curr_comp_nand_33

.subckt curr_comp_33 input1 input2 output enable vdd gnd freq=10e6
xinv1 enable phi_1 vdd gnd inv_33 size=20
xdelay1 phi_1 phi_23 vdd gnd delay_33 size=20     
xinv2 phi_1 phi_4 vdd gnd inv_33 size=20 
xinv3 phi_23 phi_out_pre vdd gnd inv_33 size=20
xdelay2 phi_out_pre phi_out_pre2 vdd gnd delay_33 size=20
xdelay3 phi_out_pre2 phi_out_pre3 vdd gnd delay_33 size=20
xdelay4 phi_out_pre3 phi_out vdd gnd delay_33 size=20

m1 input1 phi_4 n1 gnd NMOS_VDDL33 L='2*lamda' W='4*lamda'
m2 input2 phi_4 n2 gnd NMOS_VDDL33 L='2*lamda' W='4*lamda'

m3 n1 phi_23 gnd gnd NMOS_VDDL33 L='2*lamda' W='4*lamda'
m4 n2 phi_23 gnd gnd NMOS_VDDL33 L='2*lamda' W='4*lamda'

c1 n1 n3 10p
c2 n2 n4 10p
xcurr_comp_stage1 n3 n4 n6 n5 vdd gnd curr_comp_stage1_33
m5 n3 phi_1 n5 gnd NMOS_VDDL33 L='2*lamda' W='4*lamda'
m6 n4 phi_1 n6 gnd NMOS_VDDL33 L='2*lamda' W='4*lamda'

c3 n5 n7 100p
c4 n6 n8 100p
xcurr_comp_stage2 n7 n8 n10 n9 vdd gnd curr_comp_stage2_33
m7 n7 phi_23 n9 gnd NMOS_VDDL33 L='2*lamda' W='4*lamda'
m8 n8 phi_23 n10 gnd NMOS_VDDL33 L='2*lamda' W='4*lamda'

xcurr_comp_stage3 n10 n9 n11 vdd gnd curr_comp_stage3_33
xcurr_comp_nand n11 phi_out output vdd gnd curr_comp_nand_33
.ends curr_comp_33

*
* delay: delay element
*
* inputs: input  
* outputs: output 
*
*
.subckt delay_33 input output vdd gnd size=2
xinv1 input n1 vdd gnd inv_33 size=size 
xinv2 n1 n2 vdd gnd inv_33 size=size 
xinv3 n2 n3 vdd gnd inv_33 size=size 
xinv4 n3 n4 vdd gnd inv_33 size=size 
xinv5 n4 n5 vdd gnd inv_33 size=size 
xinv6 n5 n6 vdd gnd inv_33 size=size 
xinv7 n6 n7 vdd gnd inv_33 size=size 
xinv8 n7 n8 vdd gnd inv_33 size=size 
xinv9 n8 n9 vdd gnd inv_33 size=size 
xinv10 n9 output vdd gnd inv_33 size=size 
.ends delay_33

*
* edge_detector: detect edge 1->0 and output a 1->0->1 pulse. 
*              : normally stay at 1.  
*
* inputs: input (the input signal to be detected).  
* outputs: output signal. 
*
.subckt edge_detector_33 input output vdd gnd
xdelay output output_delay vdd gnd delay_33
xnd0 n2 output_delay n1 vdd gnd nand2_33
xnd1 n1 input n2 vdd gnd nand2_33
xnd2 n1 input n3 vdd gnd nand2_33
xnd3 n2 input n4 vdd gnd nand2_33
xnd4 n3 n5 output vdd gnd nand2_33
xnd5 n4 output n5 vdd gnd nand2_33
.ends edge_detector_33

*
* buck_pfm : pulse frequency modulation buck DC/DC converter. 
*
* inputs: 
* outputs:
*
*
.subckt buck_pfm_33 enable vdd_in gnd_in vdd_out gnd_out comp_vdd  
+ freq=4e6 vdd_level=3.3 vss_level=0 pt_size='240000*lamda' lf=100n cf=0.8u csnub=0.01n pulse_time=19n
vclock clock gnd_in pulse(vss_level vdd_level 0 0.2n 0.2n pulse_time '1/freq')

xnd1 enable clock ns1 vdd_in gnd_in nand2_33  
xrs1 ns1 clock nouse1 n1_pre vdd_in gnd_in latch_rs_33

* n4 is the control of the n power transistor. 
*xinv1 n3 n3_inv vdd_in gnd_in inv 
*xand1 n3_inv n1_pre n1 vdd_in gnd_in and2 

xdrive1 n1_pre n2 vdd_in gnd_in driver6_33 size=pt_size   
xedge1 n2 n6 vdd_in gnd_in edge_detector_33
xrs2 n6 n5 n3 nouse2 vdd_in gnd_in latch_rs_33   
xdrive2 n3 n4 vdd_in gnd_in driver6_33 size=pt_size   
mptpmos nx n2 vdd_in vdd_in PMOS_VDDL33 L='2*lamda' W=pt_size
mptnmos nx n4 gnd_in gnd_in NMOS_VDDL33 L='2*lamda' W='pt_size *2 /5'
xcomp gnd_in nx n5 n4 comp_vdd gnd_in curr_comp_33 
l1 nx vdd_out lf    
c1 vdd_out gnd_out cf
c2 nx gnd_out csnub 
.ends buck_pfm_33

*
* buck_pwm: pulse width modulation buck DC/DC converter.  
*
*
.subckt buck_pwm_33 vdd_in gnd_in vref vref2 vdd_out gnd_out  
+ freq=5e6 pt_size='480000*lamda' vdd_level=3.3 vss_level=0.0 lf=135n cf=0.8u csnub=0.5n   

vtriangle1 ntriangle1 gnd_in pulse(0 vdd_level 0.0 '0.5/freq' '0.5/freq' 0.0 '1.0/freq')
vtriangle2 ntriangle2 gnd_in pulse(0 vdd_level '0.023/freq' '0.505/freq' '0.19/freq' 0.0 '1.0/freq')
xcomp1 ntriangle1 vref nctrl1 vdd_in gnd_in volt_comp_33 vc_freq=500e6 
xcomp2 ntriangle2 vref2 nctrl2_pre vdd_in gnd_in volt_comp_33 vc_freq=500e6

xdelay1 nctrl2_pre nctrl2 vdd_in gnd_in delay_33 size=1

*vctrl1 nctrl1 gnd_in pulse(0 vdd_level '0.3/freq' 0.1n 0.1n '0.4/freq' '1.0/freq') 
*vctrl2 nctrl2 gnd_in pulse(0 vdd_level 0 0.1n 0.1n '0.6/freq' '1.0/freq') 

xdriver1 nctrl1 n1 vdd_in gnd_in driver6_33 size='pt_size'
xdriver2 nctrl2 n2 vdd_in gnd_in driver6_33 size='pt_size * 2 / 5'
m1 nvx n1 vdd_in vdd_in  PMOS_VDDL33 L='2*lamda' W=pt_size
m2 nvx n2 gnd_in gnd_in NMOS_VDDL33 L='2*lamda' W='pt_size *2 / 5' 
csnub nvx gnd_in csnub 
lf nvx vdd_out lf
cf vdd_out gnd_out cf
.ends buck_pwm_33
