*
* testing the PFM DC/DC converter.
*
*

.include "../technology/100nm_nominal_H"
.include "../subckt/basic33.sp"
.include "../subckt/vc33.sp"
.include "../subckt/buck33.sp"

.param param_mu_p=0.045 
.param param_mu_n=0.15
.param param_cox=0.000138

.param lamda=0.05u
.param param_rload=10

.param param_vdd = 3.3
.param param_ref = 1.3
.param charge_pulse=18n
.param param_cf=200n
.param param_lf=75n
.param param_csnub=0.001n
.param param_pt_size='320000*lamda'

xcomp ref nvdd_out enable nvdd_volt_comp 0 vc_33 
xpfm enable nvdd_pfm 0 nvdd_out 0 nvdd_curr_comp mp_pfm_33 lf=param_lf 
+ cf=param_cf csnub=param_csnub freq=15e6 pulse_time=charge_pulse pt_size=param_pt_size
*xpfm enable nvdd_pfm 0 nvdd_out 0 nvdd_curr_comp buck_pfm_33 lf=param_lf 
*+ cf=param_cf csnub=param_csnub freq=15e6 pulse_time=charge_pulse pt_size=param_pt_size
rload nvdd_out 0 param_rload

vvdd1 nvdd_pfm 0 param_vdd
vvdd2 nvdd_volt_comp 0 param_vdd
vvdd3 nvdd_curr_comp 0 param_vdd
vref ref 0 param_ref

.ic v(nvdd_out) 0.0

.options post measout probe CONVERGE=1 GMINDC=1.0000E-12
.probe v(nvdd_out) v(ref) v(enable)  v(nvdd_pfm)
+ v(xpfm.ns1_mp1) v(xpfm.n1_mp1) v(xpfm.n2_mp1) v(xpfm.nx_mp1) v(xpfm.clock_mp1) i(xpfm.l1_mp1) 
+ v(xpfm.n3_mp1) v(xpfm.n4_mp1) v(xpfm.n5_mp1) v(xpfm.n6_mp1) 
+ v(xpfm.ns1_mp2) v(xpfm.n1_mp2) v(xpfm.n2_mp2) v(xpfm.nx_mp2) v(xpfm.clock_mp2) i(xpfm.l1_mp2) 
+ v(xpfm.n3_mp2) v(xpfm.n4_mp2) v(xpfm.n5_mp2) v(xpfm.n6_mp2) 
+ v(xpfm.xcomp_mp1.n1) v(xpfm.xcomp_mp1.n4_mp1) v(xpfm.xcomp_mp1.n5) v(xpfm.xcomp_mp1.n6) v(xpfm.xcomp_mp1.n7) 
+ v(xpfm.xcomp_mp1.n8) v(xpfm.xcomp_mp1.n9) v(xpfm.xcomp_mp1.n10) v(xpfm_mp1.n7)
+ v(xpfm.xcomp_mp2.n1) v(xpfm.xcomp_mp2.n4_mp1) v(xpfm.xcomp_mp2.n5) v(xpfm.xcomp_mp2.n6) v(xpfm.xcomp_mp2.n7) 
+ v(xpfm.xcomp_mp2.n8) v(xpfm.xcomp_mp2.n9) v(xpfm.xcomp_mp2.n10) v(xpfm_mp2.n7)


* These are measured results. 
.meas total_power avg p(vvdd1) from=2.0u to=4.0u
.meas volt_comp_power avg p(vvdd2) from=2.0u to=4.0u 
.meas curr_comp_power avg p(vvdd3) from=2.0u to=4.0u
.meas pt_power1 avg p(xpfm.mptpmos) from=2.0u to=4.0u
.meas pt_power2 avg p(xpfm.mptnmos) from=2.0u to=4.0u
.meas lf_power avg p(xpfm.l1) from=2.0u to=4.0u
.meas driver_power avg p(xpfm.vdriver) from=2.0u to=4.0u
.meas max_output max v(nvdd_out) from=2.0u to=4.0u 
.meas min_output min v(nvdd_out) from=2.0u to=4.0u  
.meas loading avg p(rload) from=2.0u to=4.0u 
.meas efficiency param=' loading /(- total_power - volt_comp_power - curr_comp_power)'
.meas ripple1 param='(max_output - param_ref)/param_ref'
.meas ripple2 param='(param_ref - min_output)/param_ref'
.meas ripple param='max(ripple1, ripple2)'

* Estimated Power transistor resistance
.meas est_pmos_res param='2 * lamda /(param_pt_size * param_mu_p * param_cox * (param_vdd + 1.65))'
.meas est_nmos_res param='5 * 2 * lamda /(2 * param_pt_size * param_mu_n * param_cox * (param_vdd - 1.32))'

* The following are results from the model.  
.meas est_peak_curr param='(param_vdd - param_ref) * charge_pulse / param_lf'
.meas duty_ratio param='param_ref / param_vdd'
.meas max_load_power param='0.5 * (param_vdd - param_ref) * param_ref * charge_pulse / param_lf'
.meas est_ripple  param='(param_vdd - param_ref) * charge_pulse * charge_pulse / (param_lf * param_cf * duty_ratio)'
.meas est_deliver_energy param='0.5*est_peak_curr*param_ref*charge_pulse'
.meas est_switch_energy param=
+ '0.5*param_csnub*((param_vdd-param_ref)*(param_vdd-param_ref) + param_vdd*param_vdd + param_ref*param_ref)'  
.meas est_conduct_power param='(est_nmos_res + est_pmos_res)* est_peak_curr * est_peak_curr / 6'
.meas eff param='1 - (est_switch_energy + est_conduct_power * charge_pulse * duty_ratio)/est_deliver_energy'
.tran 100n 4u

.end
