*
* This file contains all basic cells. 
* including nand2, and2, inv, or2 latch_rs, and driver6  
*

*
* nand2: A nand2_33 gate
*
* inputs:  input1 
*          input2 
* outputs: output
* power: vdd, gnd
*
.subckt nand2_33 input1 input2 output vdd gnd size=1
mn1 n1 input1 gnd gnd NMOS_VDDL33 L='2*lamda' W='size*8*lamda'
mn2 output input2 n1 gnd NMOS_VDDL33 L='2*lamda' W='size*8*lamda'
mp1 output input1 vdd vdd PMOS_VDDL33 L='2*lamda' W='size*10*lamda'
mp2 output input2 vdd vdd PMOS_VDDL33 L='2*lamda' W='size*10*lamda'
.ends nand2_33

*
* inv: An inverter 
*
* inputs:  input1 
*          input2 
* outputs: output
* power: vdd, gnd
*
.subckt inv_33 input output vdd gnd size=1
mn output input gnd gnd NMOS_VDDL33 L='2*lamda' W='size * 4*lamda'
mp output input vdd vdd PMOS_VDDL33 L='2*lamda' W='size * 10*lamda'
.ends inv_33

*
* and2: two-input and gate
*
* inputs: input1 
*         input2
* outputs: output
* power: vdd, gnd
*
.subckt and2_33 input1 input2 output vdd gnd size=1 
xnand2 input1 input2 n1 vdd gnd nand2_33 size='size' 
xinv n1 output vdd gnd inv_33 size='size'
.ends and2_33

*
* or2: two-input or gate
*
* inputs: input1 
*         input2
* outputs: output
* power: vdd, gnd
*
.subckt or2_33 input1 input2 output vdd gnd size=1 
xinv1 input1 n1 vdd gnd inv_33 size='size'
xinv2 input2 n2 vdd gnd inv_33 size='size' 
xnand2 n1 n2 output vdd gnd nand2_33 size='size' 
.ends or2_33

*
* latch_rs:  A RS Latch 
*
* inputs: set 
*         reset 
* outputs: q
*          qb
* power: vdd, gnd
*
.subckt latch_rs_33 set reset q qb vdd gnd
.ic v(set) 0.0
xnand1 set qb q vdd gnd nand2_33
xnand2 reset q qb vdd gnd nand2_33
.ends latch_rs_33

*
* driver6: A 6-level buffer driver
*
* inputs: input 
* outputs: output
* power: vdd_in, gnd_in
* parameters: size (size of the drived transistor).
*             tapering (tapering factor, default is 6). 
*
.subckt driver6_33 input output vdd_in gnd_in size='480000 * 2 * lamda' tapering=6
mbuf0_p nvx0 input vdd_in vdd_in PMOS_VDDL33 L='2*lamda' 
+ W='size * 5/ (7 * tapering * tapering * tapering * tapering * tapering * tapering)'
mbuf0_n nvx0 input gnd_in gnd_in NMOS_VDDL33
+ L='2*lamda' W='size * 2/ (7 * tapering * tapering * tapering * tapering * tapering * tapering)'

mbuf1_p nvx1 nvx0 vdd_in vdd_in PMOS_VDDL33 L='2*lamda' 
+ W='size * 5/ (7 * tapering * tapering * tapering * tapering * tapering)'
mbuf1_n nvx1 nvx0 gnd_in gnd_in NMOS_VDDL33
+ L='2*lamda' W='size * 2/ (7 * tapering * tapering * tapering * tapering * tapering )'

mbuf2_p nvx2 nvx1 vdd_in vdd_in PMOS_VDDL33
+L='2*lamda' W='size * 5/ (7 * tapering * tapering * tapering * tapering )'
mbuf2_n nvx2 nvx1 gnd_in gnd_in NMOS_VDDL33
+L='2*lamda' W='size * 2/ (7 * tapering * tapering * tapering * tapering )'

mbuf3_p nvx3 nvx2 vdd_in vdd_in PMOS_VDDL33
+ L='2*lamda' W='size * 5/ (7 * tapering * tapering * tapering )'
mbuf3_n nvx3 nvx2 gnd_in gnd_in NMOS_VDDL33
+ L='2*lamda' W='size * 2/ (7 * tapering * tapering * tapering )'

mbuf4_p nvx4 nvx3 vdd_in vdd_in PMOS_VDDL33
+ L='2*lamda' W='size * 5/ (7 * tapering * tapering)'
mbuf4_n nvx4 nvx3 gnd_in gnd_in NMOS_VDDL33
+ L='2*lamda' W='size * 2/ (7 * tapering * tapering)'

mbuf5_p output nvx4 vdd_in vdd_in PMOS_VDDL33
+ L='2*lamda' W='size * 5/ (7 * tapering)'
mbuf5_n output nvx4 gnd_in gnd_in NMOS_VDDL33
+ L='2*lamda' W='size * 2/ (7 * tapering)'
.ends driver6_33

*
* driver8: A 6-level buffer driver
*
* inputs: input 
* outputs: output
* power: vdd_in, gnd_in
* parameters: size (size of the drived transistor).
*             tapering (tapering factor, default is 6). 
*
.subckt driver8_33 input output vdd_in gnd_in size='800000 * 2 * lamda' tapering=5
mbuf0_p nvx0 input vdd_in vdd_in PMOS_VDDL33 L='2*lamda' 
+ W='size * 5/ (7 * tapering * tapering * tapering * tapering * tapering * tapering * tapering * tapering)'
mbuf0_n nvx0 input gnd_in gnd_in NMOS_VDDL33
+ L='2*lamda' W='size * 2/ (7 * tapering * tapering * tapering * tapering * tapering * tapering * tapering * tapering)'

mbuf1_p nvx1 nvx0 vdd_in vdd_in PMOS_VDDL33 L='2*lamda' 
+ W='size * 5/ (7 * tapering * tapering * tapering * tapering * tapering * tapering * tapering)'
mbuf1_n nvx1 nvx0 gnd_in gnd_in NMOS_VDDL33
+ L='2*lamda' W='size * 2/ (7 * tapering * tapering * tapering * tapering * tapering * tapering * tapering )'

mbuf2_p nvx2 nvx1 vdd_in vdd_in PMOS_VDDL33
+L='2*lamda' W='size * 5/ (7 * tapering * tapering * tapering * tapering * tapering * tapering )'
mbuf2_n nvx2 nvx1 gnd_in gnd_in NMOS_VDDL33
+L='2*lamda' W='size * 2/ (7 * tapering * tapering * tapering * tapering * tapering * tapering )'

mbuf3_p nvx3 nvx2 vdd_in vdd_in PMOS_VDDL33
+ L='2*lamda' W='size * 5/ (7 * tapering * tapering * tapering * tapering * tapering )'
mbuf3_n nvx3 nvx2 gnd_in gnd_in NMOS_VDDL33
+ L='2*lamda' W='size * 2/ (7 * tapering * tapering * tapering * tapering * tapering )'

mbuf4_p nvx4 nvx3 vdd_in vdd_in PMOS_VDDL33
+ L='2*lamda' W='size * 5/ (7 * tapering * tapering * tapering * tapering)'
mbuf4_n nvx4 nvx3 gnd_in gnd_in NMOS_VDDL33
+ L='2*lamda' W='size * 2/ (7 * tapering * tapering * tapering * tapering)'

mbuf5_p nvx5 nvx4 vdd_in vdd_in PMOS_VDDL33
+ L='2*lamda' W='size * 5/ (7 * tapering * tapering * tapering)'
mbuf5_n nvx5 nvx4 gnd_in gnd_in NMOS_VDDL33
+ L='2*lamda' W='size * 2/ (7 * tapering * tapering * tapering)'

mbuf6_p nvx6 nvx5 vdd_in vdd_in PMOS_VDDL33
+ L='2*lamda' W='size * 5/ (7 * tapering * tapering )'
mbuf6_n nvx6 nvx5 gnd_in gnd_in NMOS_VDDL33
+ L='2*lamda' W='size * 2/ (7 * tapering * tapering )'

mbuf7_p output nvx6 vdd_in vdd_in PMOS_VDDL33
+ L='2*lamda' W='size * 5/ (7 * tapering )'
mbuf7_n output nvx6 gnd_in gnd_in NMOS_VDDL33
+ L='2*lamda' W='size * 2/ (7 * tapering )'

.ends driver8_33

*
* ic10: inverter chain with 10 levels. 
*
* inputs:  input1 
* outputs: output
* power: vdd, gnd
*
.subckt ic10 input output vdd_in gnd_in size=10 
m0_p nvx0 input vdd_in vdd_in PMOS L='2*lamda' W='size*5*lamda'  
m0_n nvx0 input gnd_in gnd_in NMOS L='2*lamda' W='size*2*lamda'  
m1_p nvx1 nvx0 vdd_in vdd_in PMOS L='2*lamda' W='size*5*lamda'  
m1_n nvx1 nvx0 gnd_in gnd_in NMOS L='2*lamda' W='size*2*lamda'  
m2_p nvx2 nvx1 vdd_in vdd_in PMOS L='2*lamda' W='size*5*lamda'  
m2_n nvx2 nvx1 gnd_in gnd_in NMOS L='2*lamda' W='size*2*lamda'  
m3_p nvx3 nvx2 vdd_in vdd_in PMOS L='2*lamda' W='size*5*lamda'  
m3_n nvx3 nvx2 gnd_in gnd_in NMOS L='2*lamda' W='size*2*lamda'  
m4_p nvx4 nvx3 vdd_in vdd_in PMOS L='2*lamda' W='size*5*lamda'  
m4_n nvx4 nvx3 gnd_in gnd_in NMOS L='2*lamda' W='size*2*lamda'  
m5_p nvx5 nvx4 vdd_in vdd_in PMOS L='2*lamda' W='size*5*lamda'  
m5_n nvx5 nvx4 gnd_in gnd_in NMOS L='2*lamda' W='size*2*lamda'  
m6_p nvx6 nvx5 vdd_in vdd_in PMOS L='2*lamda' W='size*5*lamda'  
m6_n nvx6 nvx5 gnd_in gnd_in NMOS L='2*lamda' W='size*2*lamda'  
m7_p nvx7 nvx6 vdd_in vdd_in PMOS L='2*lamda' W='size*5*lamda'  
m7_n nvx7 nvx6 gnd_in gnd_in NMOS L='2*lamda' W='size*2*lamda'  
m8_p nvx8 nvx7 vdd_in vdd_in PMOS L='2*lamda' W='size*5*lamda'  
m8_n nvx8 nvx7 gnd_in gnd_in NMOS L='2*lamda' W='size*2*lamda'  
m9_p nvx9 nvx8 vdd_in vdd_in PMOS L='2*lamda' W='size*5*lamda'  
m9_n nvx9 nvx8 gnd_in gnd_in NMOS L='2*lamda' W='size*2*lamda'  
m10_p output nvx9 vdd_in vdd_in PMOS L='2*lamda' W='size*5*lamda'  
m10_n output nvx9 gnd_in gnd_in NMOS L='2*lamda' W='size*2*lamda'  
.ends ic10

*
* ic20: inverter chain with 20 levels. 
*
* inputs:  input1 
* outputs: output
* power: vdd, gnd
*
.subckt ic20 input output vdd_in gnd_in size=10
xic1 input nvx0 vdd_in gnd_in ic10 size=size
xic2 nvx0 output vdd_in gnd_in ic10 size=size
.ends ic20

* ic40: inverter chain with 40 levels. 
*
* inputs:  input1 
* outputs: output
* power: vdd, gnd
*
.subckt ic40 input output vdd_in gnd_in size=10
xic1 input nvx0 vdd_in gnd_in ic20 size=size
xic2 nvx0 output vdd_in gnd_in ic20 size=size
.ends ic40

* ic80: inverter chain with 80 levels. 
*
* inputs:  input
* outputs: output
* power: vdd, gnd
*
.subckt ic80 input output vdd_in gnd_in size=10
xic1 input nvx0 vdd_in gnd_in ic40 size=size
xic2 nvx0 output vdd_in gnd_in ic40 size=size
.ends ic80

*
* D flip-flop
*
.subckt dff_33 input clk q qb vdd gnd

* master
xinv1 input inputb vdd gnd inv_33
xinv2 clk clkb vdd gnd inv_33
xnand1 input clkb  n1 vdd gnd nand2_33
xnand2 inputb clkb n2 vdd gnd nand2_33
xnand3 n1 n4 n3 vdd gnd nand2_33
xnand4 n3 n2 n4 vdd gnd nand2_33

.ic v(n3) 0

* slave
xnand5 n3 clk n5 vdd gnd nand2_33
xnand6 n4 clk n6 vdd gnd nand2_33
xnand7 n5 qb q vdd gnd nand2_33
xnand8 n6 q qb vdd gnd nand2_33

.ic v(q) 0

.ends dff_33
