*
* This file contains the implementation of PWM and PFM buck circuits. 
*

*
* volt_comp: A voltage comparator from Anthorny J. Stratakos's dissertation.
*            Also reference to the paper "A high-speed CMOS comparator with
*            8-b Resolution".
* inputs: input1, input2 (two inputs to be compared).
* outputs: output (if input1 > input2, output high-level, otherwise, low level). 
* power: vdd, gnd 
* parameters: freq (operation frequency of the control signal)
*
.subckt vc_33 input1 input2 output vdd gnd vc_freq=2000e6 vdd_level=3.3 vss_level=0

vphi2 phi2 gnd pulse (vss_level vdd_level 0 '0.01/vc_freq' '0.01/vc_freq' '0.49/vc_freq' '1.0/vc_freq')
vphi1 phi1 gnd pulse (vss_level vdd_level '0.64/vc_freq' '0.01/vc_freq' '0.01/vc_freq' '0.34/vc_freq' '1.0/vc_freq')

* current source
i_bias n1 gnd 10u
m13 n1 n1 vdd vdd PMOS L='2*lamda' W='100*lamda'   
m3 n2 n1 vdd vdd PMOS L='2*lamda' W='200*lamda'   

* input stage 
m1 n2 input1 nb vdd PMOS L='2*lamda' W='200*lamda'
m2 n2 input2 na vdd PMOS L='2*lamda' W='200*lamda'

* N flip flop
m4 na nb gnd gnd NMOS L='2*lamda' W='15*lamda'
m5 nb na gnd gnd NMOS L='2*lamda' W='15*lamda'
m12 na phi2 nb gnd NMOS L='2*lamda' W='5*lamda'

* strobing transistors
m8 nc phi1 na gnd NMOS L='2*lamda' W='5*lamda'
m9 nd phi1 nb gnd NMOS L='2*lamda' W='5*lamda'

* P flip flops
m6 nc nd vdd vdd PMOS L='2*lamda' W='35*lamda'
m7 nd nc vdd vdd PMOS L='2*lamda' W='35*lamda'
m10 nc phi1 vdd vdd PMOS L='2*lamda' W='35*lamda'
m11 nd phi1 vdd vdd PMOS L='2*lamda' W='35*lamda'

xrs nc nd output1 nqb vdd gnd latch_rs_33 
xinv output1 output vdd gnd inv_33 

.ends vc_33
