*
* testing the mutual inductance  
*
.include "../technology/100nm_nominal_H"
.include "../subckt/vc33.sp"
.include "../subckt/basic33.sp"
.include "../subckt/buck33.sp"
.include "../subckt/opamp.sp"

.param lamda=0.050u

.param param_mu_p=0.045
.param param_mu_n=0.15
.param param_cox=0.0138
.param param_rload=4
.param param_ref=2.1

.param pt_size='1920000*lamda'
.param lf_value=250n
.param cf_value=300u
.param csnub_value=0.5n  

* serial connected inductance and resistance
.subckt lr input output lval=1n rval=1m
l1 input n1 lval 
r1 n1 output rval 
.ends lr

* serial connected capacitance and resistance and inductance 
.subckt crl input output cval=1u rval=1m lval=1n
c1 input n1 cval 
r1 n1 n2 rval 
l1 n2 output lval
.ends crl

* a simpel LC DC/DC converter.
xdriver1 npctrl nctrl1 nvdd 0 driver8_33 size='pt_size'
xdriver2 nnctrl nctrl2 nvdd 0 driver8_33 size='pt_size * 2 / 5'

*xdriver1 nctrl nctrl1 nvdd 0 driver8_33 size='pt_size'
*xdriver2 nctrl nctrl2 nvdd 0 driver8_33 size='pt_size * 2 / 5'

m1 nvx nctrl1 nvdd nvdd PMOS L='2*lamda' W='pt_size' 
m2 nvx nctrl2 0 0 NMOS L='2*lamda' W='pt_size *2 / 5'
csnub nvx 0 csnub_value

* Inter-connection, decap and loading
xlr0 nvx nout1 lr lval=0.2n rval=0.5m 
xlr1 nout1 nout lr lval=lf_value rval=2m 
xcrl1 nout 0 crl cval=cf_value rval=2m lval=0.01n 
xlr2 nout ndec1 lr lval=0.2n rval=0.5m 
xcrl2 ndec1 ndec2 crl cval=100n rval=0.02m lval=0.01n 
xlr3 ndec1 ndie1 lr lval=0.2n rval=0.5m 
cdie ndie1 ndie2 0.05u
rload ndie1 ndie2 param_rload
xlr4 ndie2 ndec2 lr lval=0.2n rval=0.5m 
xlr5 ndec2 nout1_gnd lr lval=0.2n rval=0.5m
xlr6 nout1_gnd 0 lr lval=0.2n rval=0.5m

* feedback control
rpwm1 nout npwm1 6k
cpwm1 npwm1 npwm 5n
xopamp1 npwm1 nref npwm nvdd 0 opamp
*xvc1 nref npwm1 npwm nvdd 0 opamp vc_freq=20e6
*xopamp2 npwm ntri nctrl nvdd 0 opamp

rtri_1 npwm npwm_tri 5k 
rtri_2 npwm_tri nref 5k 

xvc2 npwm_tri ntri nctrl_pre nvdd 0 vc_33 vc_freq=350e6
xinvz nctrl_pre nctrl nvdd 0 inv_33
*xvc2 npwm ntri nctrl nvdd 0 vc_33 vc_freq=20e6

* adaptive ZVS control
*xvc5 nref nout ncmp nvdd 0 vc_33 vc_freq=1e6
*xdff1 nvdd ncmp q1 qb1 nvdd 0 dff_33
*xdff2 q1 ncmp q2 qb2 nvdd 0 dff_33
*xdff3 q2 ncmp nzvs_enable qb3 nvdd 0 dff_33
*xdff4 q3 ncmp nzvs_enable  qb3 nvdd 0 dff_33

* feeback from nvx
xvc3 nvx nhighv nzvs_penable_pre nvdd 0 vc_33 vc_freq=50e6
xvc4 nlowv nvx nzvs_nenable_pre nvdd 0 vc_33 vc_freq=50e6

xinvx nzvs_penable_pre nzvs_penable1 nvdd 0 inv_33
xand1 nzvs_penable1 nzvs_enable nzvs_penable nvdd 0 and2_33
xor1 nzvs_penable nctrl npctrl nvdd 0 or2_33

xinvy nzvs_enable nzvs_enable_inv nvdd 0 inv_33
xor2 nzvs_nenable_pre nzvs_enable_inv nzvs_nenable nvdd 0 or2_33
xand2 nzvs_nenable nctrl nnctrl nvdd 0 and2_33 

vnvdd nvdd 0 3.3
vnref nref 0 param_ref
vntri ntri 0 pulse(0 3.3 0 350n 350n 0n 700n) 
vnzvs_enable nzvs_enable 0 pwl(0 0 150u 0 350.01u 3.3 450u 3.3)
vlow nlowv 0 0.3
vhigh nhighv 0 3.0

.ic v(nout)=0.0
.ic i(xlr1.l1)=0.0

*vctrl nctrl 0 pulse(0 3.3 0 1n 1n 499n 1u)

.options post measout probe 
.probe v(nout) v(nvx) v(nref) i(xlr1.l1) v(npctrl) v(nnctrl) v(npwm)
.measure total_power avg p(vnvdd) from=400u to=450u
.measure loading avg p(rload) from=400u to=450u
.measure ptp_power avg p(m1) from=400u to=450u
.measure ptn_power avg p(m2) from=400u to=450u
.measure nout_max max v(nout) from=400u to=450u
.measure nout_min min v(nout) from=400u to=450u
.measure ripple1 param='(nout_max - param_ref)/param_ref'
.measure ripple2 param='(param_ref - nout_min)/param_ref'
.measure efficiency param='loading/total_power'

.tran 10n 450u 

.end
