*
* testing the mutual inductance  
*
.include "../technology/100nm_nominal_H"
.include "../subckt/vc33.sp"
.include "../subckt/basic33.sp"
.include "../subckt/buck33.sp"
.include "../subckt/opamp.sp"

.param lamda=0.050u

.param param_mu_p=0.045
.param param_mu_n=0.15
.param param_cox=0.0138
.param param_rload1=4
.param param_rload2=4
.param param_ref=2.1

.param pt_size='1920000*lamda'
.param lf_value=250n
.param cf_value=300u
.param csnub_value=0.5n  

.param param_pfm_ref = 1.3
.param charge_pulse=18n
.param param_pfm_cf=200n
.param param_pfm_lf=75n
.param param_pfm_csnub=0.001n
.param param_pfm_pt_size='320000*lamda'

* serial connected inductance and resistance
.subckt lr input output lval=1n rval=1m
l1 input n1 lval 
r1 n1 output rval 
.ends lr

* serial connected capacitance and resistance and inductance 
.subckt crl input output cval=1u rval=1m lval=1n
c1 input n1 cval 
r1 n1 n2 rval 
l1 n2 output lval
.ends crl

* a simpel LC DC/DC converter.

* Inter-connection, decap and loading
xlr2 nout ndec1 lr lval=0.2n rval=0.5m 
xcrl2 ndec1 ndec2 crl cval=100n rval=0.02m lval=0.01n 
xlr3 ndec1 ndie1 lr lval=0.2n rval=0.5m 
cdie ndie1 ndie2 0.05u

*rload ndie1 ndie2 param_rload

*xcomp npfm_ref ndie1 pfm_enable nvdd2 npfm_gnd vc_33 
*xpfm pfm_enable nvdd2 npfm_gnd ndie1 npfm_gnd nvdd2 mp_pfm_33 lf=param_pfm_lf
*+ cf=param_pfm_cf csnub=param_pfm_csnub freq=15e6 pulse_time=charge_pulse pt_size=param_pfm_pt_size
*rload1 ndie1 npfm_gnd param_rload1
*rload2 npfm_gnd ndie2 param_rload2

rload2 ndie1 npfm_gnd param_rload2
xcomp npfm_ref npfm_gnd pfm_enable nvdd2 0 vc_33 
xpfm pfm_enable nvdd2 0 npfm_gnd 0 nvdd2 mp_pfm_33 lf=param_pfm_lf
+ cf=param_pfm_cf csnub=param_pfm_csnub freq=15e6 pulse_time=charge_pulse pt_size=param_pfm_pt_size
rload1 npfm_gnd ndie2 param_rload1
xlr4 ndie2 ndec2 lr lval=0.2n rval=0.5m 
xlr5 ndec2 0 lr lval=0.2n rval=0.5m

* feeback from nvx

vnvdd nout 0 sin param_ref 'param_ref * 0.02' 1e6
vnvdd2 nvdd2 0 3.3
vnpfm_ref npfm_ref 0 param_pfm_ref

.options post measout probe 
.probe v(nout) v(pfm_enable) v(ndie1) v(npfm_gnd) v(xpfm.n2_mp1) v(xpfm.n4_mp1) v(xpfm.n2_mp2) v(xpfm.n4_mp2)
+ i(xpfm.l1_mp1) v(nx_mp1) v(xpfm.n5_mp2) v(xpfm.n6_mp2) v(xpfm.clock_mp1) v(xpfm.clock_mp2) v(0) v(nvdd2) v(npfm_ref)
.measure total_power1 avg p(vnvdd) from=2u to=4u
.measure total_power2 avg p(vnvdd2) from=2u to=4u
.measure total_power param='total_power1/0.85 + total_power2'
.measure loading1 avg p(rload1) from=2u to=4u
.measure loading2 avg p(rload2) from=2u to=4u
.measure loading param='loading1 + loading2'
.measure ptp_power avg p(m1) from=2u to=4u
.measure ptn_power avg p(m2) from=2u to=4u
.measure nout_max max v(nout) from=2u to=4u
.measure nout_min min v(nout) from=2u to=4u
.measure ripple1 param='(nout_max - param_ref)/param_ref'
.measure ripple2 param='(param_ref - nout_min)/param_ref'

.measure pfm_gnd_max max v(npfm_gnd) from=2u to=4u
.measure pfm_gnd_min min v(npfm_gnd) from=2u to=4u
.measure pfm_gnd_ref param='param_pfm_ref'
.measure pfm_ripple1 param='(pfm_gnd_max - pfm_gnd_ref)/pfm_gnd_ref'
.measure pfm_ripple2 param='(pfm_gnd_ref - pfm_gnd_min)/pfm_gnd_ref'

.measure efficiency param='loading/total_power'

.tran 1n 4u 

.end
